@@ -6,7 +6,7 @@
  * Date        : 2007-11-14
  * Description : a kipi plugin to slide images.
  *
- * Copyright (C) 2007-2008 by Valerio Fuoglio <valerio dot fuoglio at gmail dot com>
+ * Copyright (C) 2007-2009 by Valerio Fuoglio <valerio dot fuoglio at gmail dot com>
  *
  * Parts of this code are based on smoothslidesaver by Carsten Weinhold
  * <carsten dot weinhold at gmx dot de>
@@ -28,7 +28,7 @@
 
 // Qt includes
 
-#include <Q3ValueList>
+#include <QList>
 #include <QImage>
 #include <QThread>
 #include <QWaitCondition>
@@ -46,7 +46,7 @@ class ImageLoadThread : public QThread
 
 public:
 
-    ImageLoadThread(Q3ValueList<QPair<QString, int> >& fileList, int width, int height);
+    ImageLoadThread(QList<QPair<QString, int> >& fileList, int width, int height);
 
     void  quit();
     void  requestNewImage();
@@ -90,7 +90,7 @@ protected:
 private:
 
     int                               m_fileIndex;
-    Q3ValueList<QPair<QString, int> > m_fileList;
+    QList<QPair<QString, int> >       m_fileList;
 
     int                               m_width, m_height;
 
