@@ -7,6 +7,7 @@
  * Description : a kipi plugin to slide images.
  *
  * Copyright (C) 2008-2009 by Valerio Fuoglio <valerio dot fuoglio at gmail dot com>
+ * Copyright (C) 2009      by Andi Clemens <andi dot clemens at gmx dot net>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -48,7 +49,7 @@ SoundItem::SoundItem(QListWidget* parent, KUrl &url)
          : QListWidgetItem(parent)
 {
     m_url = url;
-    setIcon(SmallIcon( "audio-x-generic", KIconLoader::SizeLarge, KIconLoader::DisabledState ));
+    setIcon(SmallIcon("audio-x-generic", KIconLoader::SizeLarge, KIconLoader::DisabledState));
 
     m_totalTime   = QTime(0, 0, 0);
     m_mediaObject = new Phonon::MediaObject();
@@ -60,7 +61,6 @@ SoundItem::SoundItem(QListWidget* parent, KUrl &url)
 
 SoundItem::~SoundItem()
 {
-//    delete m_mediaObject;
 }
 
 KUrl SoundItem::url()
@@ -108,17 +108,12 @@ void SoundItem::slotMediaStateChanged(Phonon::State newstate, Phonon::State /*ol
         return;
 
     long int total = m_mediaObject->totalTime();
-
     int hours      = (int)(total / (long int)( 60 * 60 * 1000 ));
-
     int mins       = (int)((total / (long int)( 60 * 1000 )) - (long int)(hours * 60));
-
     int secs       = (int)((total / (long int)1000) - (long int)(hours * 60 * 60) - (long int)(mins * 60));
-
     m_totalTime    = QTime(hours, mins, secs);
 
     m_artist       = (m_mediaObject->metaData(Phonon::ArtistMetaData)).join(",");
-
     m_title        = (m_mediaObject->metaData(Phonon::TitleMetaData)).join(",");
 
     if ( m_artist.isEmpty() && m_title.isEmpty() )
@@ -170,4 +165,20 @@ void ListSoundItems::dropEvent(QDropEvent *e)
         emit addedDropItems(urls);
 }
 
+KUrl::List ListSoundItems::fileUrls()
+{
+    KUrl::List files;
+
+    for (int i = 0; i < count(); ++i)
+    {
+        SoundItem *sitem = dynamic_cast<SoundItem*>(item(i));
+        if (sitem)
+        {
+            files << KUrl(sitem->url());
+        }
+    }
+
+    return files;
+}
+
 }  // namespace KIPIAdvancedSlideshowPlugin
