@@ -7,7 +7,7 @@
  * Description : a kipi plugin to slide images.
  *
  * Copyright (C) 2008-2009 by Valerio Fuoglio <valerio dot fuoglio at gmail dot com>
- * Copyright (C) 2009 by Andi Clemens <andi dot clemens at gmx dot net>
+ * Copyright (C) 2009      by Andi Clemens <andi dot clemens at gmx dot net>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -71,8 +71,9 @@ MainDialog::MainDialog( QWidget* parent, SharedData* sharedData)
 
     QVBoxLayout *listBoxContainerLayout = new QVBoxLayout;
     m_ImagesFilesListBox                = new ImagesList(sharedData->interface, m_ImagesFilesListBoxContainer,
-                                                         ImagesList::NoControlButtons, KIconLoader::SizeMedium);
+                                                         KIconLoader::SizeMedium);
     m_ImagesFilesListBox->listView()->header()->hide();
+
     listBoxContainerLayout->addWidget(m_ImagesFilesListBox);
     listBoxContainerLayout->setSpacing(0);
     listBoxContainerLayout->setMargin(0);
@@ -80,18 +81,6 @@ MainDialog::MainDialog( QWidget* parent, SharedData* sharedData)
 
     // --------------------------------------------------------
 
-    m_ImagesFilesButtonUp->setIcon(KIcon("arrow-up"));
-    m_ImagesFilesButtonDown->setIcon(KIcon("arrow-down"));
-    m_ImagesFilesButtonAdd->setIcon(KIcon("list-add"));
-    m_ImagesFilesButtonDelete->setIcon(KIcon("list-remove"));
-
-    m_ImagesFilesButtonUp->setText("");
-    m_ImagesFilesButtonDown->setText("");
-    m_ImagesFilesButtonAdd->setText("");
-    m_ImagesFilesButtonDelete->setText("");
-
-    // --------------------------------------------------------
-
     m_previewLabel->setMinimumWidth(ICONSIZE);
     m_previewLabel->setMinimumHeight(ICONSIZE);
 
@@ -113,6 +102,8 @@ MainDialog::~MainDialog()
 void MainDialog::readSettings()
 {
     m_openglCheckBox->setChecked(m_sharedData->opengl);
+    m_openGlFullScale->setChecked(m_sharedData->openGlFullScale);
+    m_openGlFullScale->setEnabled(m_sharedData->opengl);
     m_delaySpinBox->setValue(m_sharedData->delay);
     m_printNameCheckBox->setChecked(m_sharedData->printFileName);
     m_printProgressCheckBox->setChecked(m_sharedData->printProgress);
@@ -143,23 +134,22 @@ void MainDialog::readSettings()
 
     // --------------------------------------------------------
 
+    setupConnections();
+
     slotOpenGLToggled();
     slotPrintCommentsToggled();
     slotEffectChanged();
     slotSelection();
-
-    // --------------------------------------------------------
-
-    setupConnections();
 }
 
 void MainDialog::saveSettings()
 {
-    m_sharedData->opengl  = m_openglCheckBox->isChecked();
+    m_sharedData->opengl            = m_openglCheckBox->isChecked();
+    m_sharedData->openGlFullScale   = m_openGlFullScale->isChecked();
 
-    m_sharedData->delay   = m_sharedData->useMilliseconds ?
-                            m_delaySpinBox->value() :
-                            m_delaySpinBox->value() * 1000;
+    m_sharedData->delay             = m_sharedData->useMilliseconds ?
+                                      m_delaySpinBox->value() :
+                                      m_delaySpinBox->value() * 1000;
 
     m_sharedData->printFileName     = m_printNameCheckBox->isChecked();
     m_sharedData->printProgress     = m_printProgressCheckBox->isChecked();
@@ -198,13 +188,17 @@ void MainDialog::saveSettings()
         effectNames = SlideShowGL::effectNamesI18N();
 
         for (it = effectNames.constBegin(); it != effectNames.constEnd(); ++it)
+        {
             effects.insert(it.key(), it.value());
+        }
 
         // Load Ken Burns effect
         effectNames = SlideShowKB::effectNamesI18N();
 
         for (it = effectNames.constBegin(); it != effectNames.constEnd(); ++it)
+        {
             effects.insert(it.key(), it.value());
+        }
 
         QString effect;
 
@@ -231,12 +225,15 @@ void MainDialog::showNumberImages()
     if ( m_openglCheckBox->isChecked() )
         transitionDuration += 500;
 
-    if ( m_sharedData->useMilliseconds )
-        totalDuration = totalDuration.addMSecs(numberOfImages * m_delaySpinBox->text().toInt());
-    else
-        totalDuration = totalDuration.addSecs(numberOfImages * m_delaySpinBox->text().toInt());
+    if (numberOfImages != 0)
+    {
+        if ( m_sharedData->useMilliseconds )
+            totalDuration = totalDuration.addMSecs(numberOfImages * m_delaySpinBox->text().toInt());
+        else
+            totalDuration = totalDuration.addSecs(numberOfImages * m_delaySpinBox->text().toInt());
 
-    totalDuration = totalDuration.addMSecs((numberOfImages - 1) * transitionDuration);
+        totalDuration = totalDuration.addMSecs((numberOfImages - 1) * transitionDuration);
+    }
 
     m_totalTime = totalDuration;
 
@@ -256,7 +253,9 @@ void MainDialog::loadEffectNames()
     QMap<QString, QString>::Iterator it;
 
     for (it = effectNames.begin(); it != effectNames.end(); ++it)
+    {
         effects.append(it.value());
+    }
 
     m_effectsComboBox->insertItems(0, effects);
 
@@ -281,14 +280,13 @@ void MainDialog::loadEffectNamesGL()
     // Load slideshowgl effects
     effectNames = SlideShowGL::effectNamesI18N();
 
-    for (it = effectNames.begin(); it != effectNames.end(); ++it)
-        effects.append(it.value());
-
-    // Load Ken Burns effect
-    effectNames = SlideShowKB::effectNamesI18N();
+    // Add Ken Burns effect
+    effectNames.unite(SlideShowKB::effectNamesI18N());
 
     for (it = effectNames.begin(); it != effectNames.end(); ++it)
+    {
         effects.append(it.value());
+    }
 
     // Update GUI
 
@@ -296,7 +294,7 @@ void MainDialog::loadEffectNamesGL()
 
     m_effectsComboBox->insertItems(0, effects);
 
-    for (int i = 0; i < m_effectsComboBox->count(); i++)
+    for (int i = 0; i < m_effectsComboBox->count(); ++i)
     {
         if (effectNames[m_sharedData->effectNameGL] == m_effectsComboBox->itemText(i))
         {
@@ -357,7 +355,7 @@ void MainDialog::slotImagesFilesSelected(QTreeWidgetItem* item)
     if (index.isValid())
     {
         int rowindex = index.row();
-        m_label7->setText(i18nc("Image number %1", "Image #%1", QString::number(rowindex + 1)));
+        m_label7->setText(i18nc("Image number %1", "Image #%1", rowindex + 1));
     }
 }
 
@@ -368,63 +366,9 @@ void MainDialog::addItems(const KUrl::List& fileList)
     KUrl::List files = fileList;
 
     m_ImagesFilesListBox->slotAddImages(files);
-    showNumberImages();
     slotImagesFilesSelected(m_ImagesFilesListBox->listView()->currentItem());
 }
 
-void MainDialog::slotImagesFilesButtonAdd( void )
-{
-    KIPIPlugins::ImageDialog dlg(this, m_sharedData->interface, false);
-    KUrl::List urls = dlg.urls();
-
-    if (!urls.isEmpty())
-    {
-        addItems(urls);
-    }
-}
-
-void MainDialog::slotImagesFilesButtonDelete( void )
-{
-    ImagesListViewItem* item = dynamic_cast<ImagesListViewItem*>(m_ImagesFilesListBox->listView()->currentItem());
-    if (!item)
-        return;
-
-    m_ImagesFilesListBox->removeItemByUrl(item->url());
-
-    showNumberImages();
-    slotImagesFilesSelected(m_ImagesFilesListBox->listView()->currentItem());
-}
-
-void MainDialog::slotImagesFilesButtonUp( void )
-{
-    QModelIndex curIndex   = m_ImagesFilesListBox->listView()->currentIndex();
-    if (!curIndex.isValid())
-        return;
-
-    QModelIndex aboveIndex = m_ImagesFilesListBox->listView()->indexAbove(curIndex);
-    if (!aboveIndex.isValid())
-        return;
-
-    QTreeWidgetItem* temp = m_ImagesFilesListBox->listView()->takeTopLevelItem(aboveIndex.row());
-    QModelIndex curTemp   = m_ImagesFilesListBox->listView()->currentIndex();
-    m_ImagesFilesListBox->listView()->insertTopLevelItem(curIndex.row(), temp);
-}
-
-void MainDialog::slotImagesFilesButtonDown( void )
-{
-    QModelIndex curIndex   = m_ImagesFilesListBox->listView()->currentIndex();
-    if (!curIndex.isValid())
-        return;
-
-    QModelIndex belowIndex = m_ImagesFilesListBox->listView()->indexBelow(curIndex);
-    if (!belowIndex.isValid())
-        return;
-
-    QTreeWidgetItem* temp = m_ImagesFilesListBox->listView()->takeTopLevelItem(belowIndex.row());
-    QModelIndex curTemp   = m_ImagesFilesListBox->listView()->currentIndex();
-    m_ImagesFilesListBox->listView()->insertTopLevelItem(curIndex.row(), temp);
-}
-
 void MainDialog::slotOpenGLToggled( void )
 {
     if (m_openglCheckBox->isChecked())
@@ -447,6 +391,7 @@ void MainDialog::slotEffectChanged( void )
     m_printNameCheckBox->setEnabled(!isKB);
     m_printProgressCheckBox->setEnabled(!isKB);
     m_printCommentsCheckBox->setEnabled(!isKB);
+    m_openGlFullScale->setEnabled(!isKB && m_openglCheckBox->isChecked());
     m_sharedData->page_caption->setEnabled((!isKB) &&
                                            m_printCommentsCheckBox->isChecked());
 }
@@ -486,13 +431,8 @@ void MainDialog::slotSelection( void )
 
     if (m_selectedFilesButton->isChecked())
     {
-        urlList = m_sharedData->interface->currentSelection().images();
         m_ImagesFilesListBox->listView()->clear();
-
-        m_ImagesFilesButtonAdd->setEnabled(false);
-        m_ImagesFilesButtonDelete->setEnabled(false);
-        m_ImagesFilesButtonUp->setEnabled(false);
-        m_ImagesFilesButtonDown->setEnabled(false);
+        urlList = m_sharedData->interface->currentSelection().images();
     }
     else if (m_allFilesButton->isChecked())
     {
@@ -500,33 +440,30 @@ void MainDialog::slotSelection( void )
         QList<KIPI::ImageCollection> albumList;
         albumList = m_sharedData->interface->allAlbums();
 
+        m_ImagesFilesListBox->listView()->clear();
         urlList = m_sharedData->interface->currentAlbum().images();
 
         QList<KIPI::ImageCollection>::iterator it;
         for (it = albumList.begin(); it != albumList.end(); ++it)
-            if (currentPath.isParentOf((*it).path()) && !((*it).path() == currentPath))
-                urlList += (*it).images();
-
-        m_ImagesFilesButtonAdd->setEnabled(false);
-        m_ImagesFilesButtonDelete->setEnabled(false);
-        m_ImagesFilesButtonUp->setEnabled(false);
-        m_ImagesFilesButtonDown->setEnabled(false);
-    }
-
-    if ( m_customButton->isChecked() )    // Custom selected
-    {
-        m_ImagesFilesButtonAdd->setEnabled(true);
-        m_ImagesFilesButtonDelete->setEnabled(true);
-        m_ImagesFilesButtonUp->setEnabled(true);
-        m_ImagesFilesButtonDown->setEnabled(true);
-    }
-    else
-    {
-        if (!urlList.isEmpty())
         {
-            addItems(urlList);
+            if (currentPath.isParentOf((*it).path()) && !((*it).path() == currentPath))
+            {
+                urlList += (*it).images();
+            }
         }
     }
+
+    bool customize = m_customButton->isChecked();
+
+    if (!urlList.isEmpty() && !customize)
+    {
+        addItems(urlList);
+    }
+
+    m_ImagesFilesListBox->listView()->setDragEnabled(customize);
+    m_ImagesFilesListBox->listView()->setAcceptDrops(customize);
+    m_ImagesFilesListBox->listView()->setDropIndicatorShown(customize);
+    m_ImagesFilesListBox->enableControlButtons(customize);
 }
 
 void MainDialog::slotPortfolioDurationChanged ( int )
@@ -551,6 +488,12 @@ void MainDialog::slotPrintCommentsToggled( void )
     m_sharedData->page_caption->setEnabled(m_printCommentsCheckBox->isChecked());
 }
 
+void MainDialog::slotImageListChanged()
+{
+    showNumberImages();
+    slotImagesFilesSelected(m_ImagesFilesListBox->listView()->currentItem());
+}
+
 void MainDialog::setupConnections()
 {
     connect(m_sharedData->advancedPage, SIGNAL(useMillisecondsToggled()), this,
@@ -571,21 +514,12 @@ void MainDialog::setupConnections()
     connect(m_effectsComboBox, SIGNAL(activated(int)),
             this, SLOT(slotEffectChanged()));
 
+    connect(m_ImagesFilesListBox, SIGNAL( signalImageListChanged() ),
+            this, SLOT( slotImageListChanged() ));
+
     connect(m_ImagesFilesListBox, SIGNAL( signalItemClicked(QTreeWidgetItem*) ),
             this, SLOT( slotImagesFilesSelected(QTreeWidgetItem*) ));
 
-    connect(m_ImagesFilesButtonAdd, SIGNAL( clicked() ),
-            this, SLOT( slotImagesFilesButtonAdd() ));
-
-    connect(m_ImagesFilesButtonDelete, SIGNAL( clicked() ),
-            this, SLOT( slotImagesFilesButtonDelete() ));
-
-    connect(m_ImagesFilesButtonUp, SIGNAL( clicked() ),
-            this, SLOT( slotImagesFilesButtonUp() ));
-
-    connect(m_ImagesFilesButtonDown, SIGNAL( clicked() ),
-            this, SLOT( slotImagesFilesButtonDown() ));
-
     if (m_sharedData->showSelectedFilesOnly)
     {
         connect(m_selectedFilesButton, SIGNAL(toggled(bool)),
