@@ -7,7 +7,7 @@
  * Description : a kipi plugin to slide images.
  *
  * Copyright (C) 2008-2009 by Valerio Fuoglio <valerio dot fuoglio at gmail dot com>
- * Copyright (C) 2009 by Andi Clemens <andi dot clemens at gmx dot net>
+ * Copyright (C) 2009      by Andi Clemens <andi dot clemens at gmx dot net>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -26,18 +26,19 @@
 
 // Qt includes
 
+#include <QFileInfo>
 #include <QFont>
 
 // KDE includes
 
-#include <ktoolinvocation.h>
 #include <kconfig.h>
-#include <kiconloader.h>
-#include <kicon.h>
-#include <khelpmenu.h>
-#include <kpushbutton.h>
-#include <kmenu.h>
 #include <kdebug.h>
+#include <khelpmenu.h>
+#include <kicon.h>
+#include <kiconloader.h>
+#include <kmenu.h>
+#include <kpushbutton.h>
+#include <ktoolinvocation.h>
 
 // LibKIPI includes
 
@@ -66,6 +67,7 @@ public:
 SlideShowConfig::SlideShowConfig (QWidget *parent, SharedData* sharedData)
                : KPageDialog(parent), d(new SlideShowConfigPrivate)
 {
+    setObjectName("Advanced Slideshow Settings");
     setWindowTitle(i18n("Advanced Slideshow"));
 
     d->config     = new KConfig("kipirc");
@@ -144,12 +146,13 @@ SlideShowConfig::~SlideShowConfig ()
 
 void SlideShowConfig::readSettings()
 {
-    KConfigGroup grp = d->config->group("Advanced Slideshow Settings");
+    KConfigGroup grp = d->config->group(objectName());
 
     d->sharedData->opengl            = grp.readEntry("OpenGL", false);
+    d->sharedData->openGlFullScale   = grp.readEntry("OpenGLFullScale", false);
     d->sharedData->delay             = grp.readEntry("Delay", 1500);
     d->sharedData->printFileName     = grp.readEntry("Print Filename", true);
-    d->sharedData->printProgress     = grp.readEntry("Print Progress Inticator", true);
+    d->sharedData->printProgress     = grp.readEntry("Print Progress Indicator", true);
     d->sharedData->printFileComments = grp.readEntry("Print Comments", false);
     d->sharedData->loop              = grp.readEntry("Loop", false);
     d->sharedData->shuffle           = grp.readEntry("Shuffle", false);
@@ -162,13 +165,13 @@ void SlideShowConfig::readSettings()
 
     // Comments tab settings
     QFont *savedFont = new QFont();
-    savedFont->setFamily(grp.readEntry("Comments Font Family"));
-    savedFont->setPointSize(grp.readEntry("Comments Font Size", 10 ));
-    savedFont->setBold(grp.readEntry("Comments Font Bold", false));
-    savedFont->setItalic(grp.readEntry("Comments Font Italic", false));
-    savedFont->setUnderline(grp.readEntry("Comments Font Underline", false));
-    savedFont->setOverline(grp.readEntry("Comments Font Overline", false));
-    savedFont->setStrikeOut(grp.readEntry("Comments Font StrikeOut", false));
+    savedFont->setFamily(    grp.readEntry("Comments Font Family"));
+    savedFont->setPointSize( grp.readEntry("Comments Font Size", 10 ));
+    savedFont->setBold(      grp.readEntry("Comments Font Bold", false));
+    savedFont->setItalic(    grp.readEntry("Comments Font Italic", false));
+    savedFont->setUnderline( grp.readEntry("Comments Font Underline", false));
+    savedFont->setOverline(  grp.readEntry("Comments Font Overline", false));
+    savedFont->setStrikeOut( grp.readEntry("Comments Font StrikeOut", false));
     savedFont->setFixedPitch(grp.readEntry("Comments Font FixedPitch", false));
 
     d->sharedData->captionFont = savedFont;
@@ -180,8 +183,9 @@ void SlideShowConfig::readSettings()
     d->sharedData->commentsLinesLength = grp.readEntry("Comments Lines Length", 72);
 
     // Soundtrack tab
-    d->sharedData->soundtrackLoop      = grp.readEntry("Sountrack Loop", false);
-    d->sharedData->soundtrackPath      = KUrl(grp.readEntry("Sountrack Path", "" ));
+    d->sharedData->soundtrackLoop             = grp.readEntry("Soundtrack Loop", false);
+    d->sharedData->soundtrackPath             = KUrl(grp.readEntry("Soundtrack Path", "" ));
+    d->sharedData->soundtrackRememberPlaylist = grp.readEntry("Soundtrack Remember Playlist", false);
 
     // Advanced tab
     d->sharedData->useMilliseconds     = grp.readEntry("Use Milliseconds", false);
@@ -193,6 +197,25 @@ void SlideShowConfig::readSettings()
     d->sharedData->enableCache         = grp.readEntry("Enable Cache", false);
     d->sharedData->cacheSize           = grp.readEntry("Cache Size", 5);
 
+    if (d->sharedData->soundtrackRememberPlaylist)
+    {
+        QString groupName(objectName() + " Soundtrack " + d->sharedData->interface->currentAlbum().path().path());
+        KConfigGroup soundGrp = d->config->group(groupName);
+
+        // load and check playlist files, if valid, add to tracklist widget
+        QStringList playlistFiles = soundGrp.readEntry("Tracks", QStringList());
+
+        foreach (const QString& playlistFile, playlistFiles)
+        {
+            KUrl file(playlistFile);
+            QFileInfo fi(file.path());
+            if (fi.isFile())
+            {
+                d->sharedData->soundtrackUrls << file;
+            }
+        }
+    }
+
     d->sharedData->mainPage->readSettings();
     d->sharedData->captionPage->readSettings();
     d->sharedData->soundtrackPage->readSettings();
@@ -208,43 +231,56 @@ void SlideShowConfig::saveSettings()
     d->sharedData->soundtrackPage->saveSettings();
     d->sharedData->advancedPage->saveSettings();
 
-    KConfigGroup grp = d->config->group("Advanced Slideshow Settings");
-    grp.writeEntry("OpenGL", d->sharedData->opengl);
-    grp.writeEntry("Delay", d->sharedData->delay);
-    grp.writeEntry("Print Filename", d->sharedData->printFileName);
+    KConfigGroup grp = d->config->group(objectName());
+    grp.writeEntry("OpenGL",                   d->sharedData->opengl);
+    grp.writeEntry("OpenGLFullScale",          d->sharedData->openGlFullScale);
+    grp.writeEntry("Delay",                    d->sharedData->delay);
+    grp.writeEntry("Print Filename",           d->sharedData->printFileName);
     grp.writeEntry("Print Progress Indicator", d->sharedData->printProgress);
-    grp.writeEntry("Print Comments", d->sharedData->printFileComments);
-    grp.writeEntry("Loop", d->sharedData->loop);
-    grp.writeEntry("Shuffle", d->sharedData->shuffle);
-    grp.writeEntry("Use Milliseconds", d->sharedData->useMilliseconds);
-    grp.writeEntry("Enable Mouse Wheel", d->sharedData->enableMouseWheel);
+    grp.writeEntry("Print Comments",           d->sharedData->printFileComments);
+    grp.writeEntry("Loop",                     d->sharedData->loop);
+    grp.writeEntry("Shuffle",                  d->sharedData->shuffle);
+    grp.writeEntry("Use Milliseconds",         d->sharedData->useMilliseconds);
+    grp.writeEntry("Enable Mouse Wheel",       d->sharedData->enableMouseWheel);
 
     // Comments tab settings
     QFont* commentsFont = d->sharedData->captionFont;
-    grp.writeEntry("Comments Font Family", commentsFont->family());
-    grp.writeEntry("Comments Font Size", commentsFont->pointSize());
-    grp.writeEntry("Comments Font Bold", commentsFont->bold());
-    grp.writeEntry("Comments Font Italic", commentsFont->italic());
-    grp.writeEntry("Comments Font Underline", commentsFont->underline());
-    grp.writeEntry("Comments Font Overline", commentsFont->overline());
-    grp.writeEntry("Comments Font StrikeOut", commentsFont->strikeOut());
+    grp.writeEntry("Comments Font Family",     commentsFont->family());
+    grp.writeEntry("Comments Font Size",       commentsFont->pointSize());
+    grp.writeEntry("Comments Font Bold",       commentsFont->bold());
+    grp.writeEntry("Comments Font Italic",     commentsFont->italic());
+    grp.writeEntry("Comments Font Underline",  commentsFont->underline());
+    grp.writeEntry("Comments Font Overline",   commentsFont->overline());
+    grp.writeEntry("Comments Font StrikeOut",  commentsFont->strikeOut());
     grp.writeEntry("Comments Font FixedPitch", commentsFont->fixedPitch());
-    grp.writeEntry("Comments Font Color", d->sharedData->commentsFontColor);
-    grp.writeEntry("Comments Bg Color", d->sharedData->commentsBgColor);
-    grp.writeEntry("Transparent Bg", d->sharedData->transparentBg);
-    grp.writeEntry("Comments Lines Length", d->sharedData->commentsLinesLength);
-    grp.writeEntry("Effect Name (OpenGL)", d->sharedData->effectNameGL);
-    grp.writeEntry("Effect Name", d->sharedData->effectName);
+    grp.writeEntry("Comments Font Color",      d->sharedData->commentsFontColor);
+    grp.writeEntry("Comments Bg Color",        d->sharedData->commentsBgColor);
+    grp.writeEntry("Transparent Bg",           d->sharedData->transparentBg);
+    grp.writeEntry("Comments Lines Length",    d->sharedData->commentsLinesLength);
+    grp.writeEntry("Effect Name (OpenGL)",     d->sharedData->effectNameGL);
+    grp.writeEntry("Effect Name",              d->sharedData->effectName);
 
-    // Sountrack tab
-    grp.writeEntry("Sountrack Loop", d->sharedData->soundtrackLoop);
-    grp.writeEntry("Sountrack Path", d->sharedData->soundtrackPath.path());
+    // Soundtrack tab
+    grp.writeEntry("Soundtrack Loop",              d->sharedData->soundtrackLoop);
+    grp.writeEntry("Soundtrack Path",              d->sharedData->soundtrackPath.path());
+    grp.writeEntry("Soundtrack Remember Playlist", d->sharedData->soundtrackRememberPlaylist);
 
     // Advanced settings
     grp.writeEntry("KB Disable FadeInOut", d->sharedData->kbDisableFadeInOut);
     grp.writeEntry("KB Disable Crossfade", d->sharedData->kbDisableCrossFade);
-    grp.writeEntry("Enable Cache", d->sharedData->enableCache);
-    grp.writeEntry("Cache Size", d->sharedData->cacheSize);
+    grp.writeEntry("Enable Cache",         d->sharedData->enableCache);
+    grp.writeEntry("Cache Size",           d->sharedData->cacheSize);
+
+    // --------------------------------------------------------
+
+    // only save tracks when option is set and tracklist is NOT empty, to prevent deletion
+    // of older track entries
+    if (d->sharedData->soundtrackRememberPlaylist && d->sharedData->soundtrackPlayListNeedsUpdate)
+    {
+        QString groupName(objectName() + " Soundtrack " + d->sharedData->interface->currentAlbum().path().path());
+        KConfigGroup soundGrp = d->config->group(groupName);
+        soundGrp.writeEntry("Tracks", d->sharedData->soundtrackUrls.toStringList());
+    }
 
     d->config->sync();
 }
