@@ -4,9 +4,9 @@
  * Date  : 2004-01-19
  * Description :
  *
- * Copyright (C) 2004 by Renchi Raju <renchi@pooh.tam.uiuc.edu>
+ * Copyright (C) 2004      by Renchi Raju <renchi@pooh.tam.uiuc.edu>
  * Copyright (C) 2006-2009 by Valerio Fuoglio <valerio.fuoglio@gmail.com>
- * Copyright (C) 2009 by Andi Clemens <andi dot clemens at gmx dot net>
+ * Copyright (C) 2009      by Andi Clemens <andi dot clemens at gmx dot net>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -31,32 +31,31 @@
 
 // Qt includes
 
-#include <QList>
-#include <QTimer>
-#include <QPixmap>
 #include <QApplication>
-#include <QEvent>
 #include <QCursor>
-#include <QImage>
-#include <QPainter>
+#include <QDesktopWidget>
+#include <QEvent>
 #include <QFileInfo>
 #include <QFontMetrics>
-#include <QMatrix>
+#include <QImage>
 #include <QKeyEvent>
+#include <QList>
+#include <QMatrix>
 #include <QMouseEvent>
-#include <QWheelEvent>
-#include <QDesktopWidget>
-#include <QSvgRenderer>
 #include <QPainter>
+#include <QPixmap>
+#include <QSvgRenderer>
+#include <QTimer>
+#include <QWheelEvent>
 
 // KDE includes
 
+#include <kconfiggroup.h>
 #include <kconfig.h>
-#include <klocale.h>
 #include <kdebug.h>
 #include <kdeversion.h>
 #include <kglobalsettings.h>
-#include <KConfigGroup>
+#include <klocale.h>
 #include <kstandarddirs.h>
 
 namespace KIPIAdvancedSlideshowPlugin
@@ -267,7 +266,6 @@ void SlideShowGL::keyPressEvent(QKeyEvent *event)
         return;
 
     m_slidePlaybackWidget->keyPressEvent(event);
-
     m_playbackWidget->keyPressEvent(event);
 }
 
@@ -377,16 +375,16 @@ QMap<QString, QString> SlideShowGL::effectNamesI18N()
 {
     QMap<QString, QString> effects;
 
-    effects["None"]    = i18n("None");
-    effects["Bend"]    = i18n("Bend");
-    effects["Blend"]   = i18n("Blend");
-    effects["Cube"]    = i18n("Cube");
-    effects["Fade"]    = i18n("Fade");
-    effects["Flutter"] = i18n("Flutter");
-    effects["In Out"]  = i18n("In Out");
-    effects["Rotate"]  = i18n("Rotate");
-    effects["Slide"]   = i18n("Slide");
-    effects["Random"]  = i18n("Random");
+    effects["None"]    = i18nc("Filter Effect: No effect",     "None");
+    effects["Bend"]    = i18nc("Filter Effect: Bend",          "Bend");
+    effects["Blend"]   = i18nc("Filter Effect: Blend",         "Blend");
+    effects["Cube"]    = i18nc("Filter Effect: Cube",          "Cube");
+    effects["Fade"]    = i18nc("Filter Effect: Fade",          "Fade");
+    effects["Flutter"] = i18nc("Filter Effect: Flutter",       "Flutter");
+    effects["In Out"]  = i18nc("Filter Effect: In Out",        "In Out");
+    effects["Rotate"]  = i18nc("Filter Effect: Rotate",        "Rotate");
+    effects["Slide"]   = i18nc("Filter Effect: Slide",         "Slide");
+    effects["Random"]  = i18nc("Filter Effect: Random effect", "Random");
 
     return effects;
 }
@@ -493,7 +491,11 @@ void SlideShowGL::loadImage()
                                           Qt::ScaleMin);*/
         montage(image, black);
 
-        black = black.scaled(m_width, m_height);
+        if (!m_sharedData->openGlFullScale)
+        {
+            black = black.scaled(m_width, m_height,
+                                 Qt::IgnoreAspectRatio, Qt::SmoothTransformation);
+        }
 
         if (m_sharedData->printFileName)
             printFilename(black);
@@ -547,11 +549,11 @@ void SlideShowGL::montage(QImage& top, QImage& bot)
 
     unsigned int *bdata = 0;
 
-    for (int y = sh; y < eh; y++)
+    for (int y = sh; y < eh; ++y)
     {
         bdata = (unsigned int*) bot.scanLine(y) + sw;
 
-        for (int x = 0; x < tw; x++)
+        for (int x = 0; x < tw; ++x)
         {
             *(bdata++) = *(tdata++);
         }
@@ -562,62 +564,26 @@ void SlideShowGL::printFilename(QImage& layer)
 {
     QFileInfo fileinfo(m_fileList[m_fileIndex].first);
     QString filename = fileinfo.fileName();
+    QPixmap pix      = generateOutlinedTextPixmap(filename);
 
-    QFont fn(font());
-    fn.setPointSize(fn.pointSize());
-    fn.setBold(true);
-
-    QFontMetrics fm(fn);
-    QRect rect = fm.boundingRect(filename);
-    rect.adjust( 0, 0, 2, 2 );
-
-    QPixmap pix(rect.width(), rect.height());
-    pix.fill(Qt::transparent);
-
-    QPainter p(&pix);
-    p.setPen(Qt::white);
-    p.setFont(fn);
-    p.drawText(1, fn.pointSize() + 1 , filename);
-    p.end();
+    // --------------------------------------------------------
 
     QPainter painter;
     painter.begin(&layer);
-    QRect target = QRect(m_xMargin, m_height - rect.height() - m_yMargin, rect.width(), rect.height());
-    QRect source = pix.rect();
-    painter.drawPixmap(target, pix, source);
+    painter.drawPixmap(m_xMargin, layer.height() - m_yMargin - pix.height(), pix);
     painter.end();
-
 }
 
 void SlideShowGL::printProgress(QImage& layer)
 {
-    QString progress(QString::number(m_fileIndex + 1) + "/" + QString::number(m_fileList.count()));
+    QString progress(QString::number(m_fileIndex + 1) + '/' + QString::number(m_fileList.count()));
 
-    QFont fn(font());
-    fn.setPointSize(fn.pointSize());
-    fn.setBold(true);
-
-    QFontMetrics fm(fn);
-    QRect rect = fm.boundingRect(progress);
-    rect.adjust( 0, 0, 2, 2 );
-
-    QPixmap pix(rect.width(), rect.height());
-    pix.fill(Qt::transparent);
-
-    QPainter p(&pix);
-
-    p.setPen(Qt::white);
-    p.setFont(fn);
-    p.drawText(1, fn.pointSize() + 1 , progress);
-    p.end();
+    QPixmap pix = generateOutlinedTextPixmap(progress);
 
     QPainter painter;
     painter.begin(&layer);
-    QRect target = QRect(m_width - rect.width() - m_xMargin, m_yMargin, rect.width(), rect.height());
-    QRect source = pix.rect();
-    painter.drawPixmap(target, pix, source);
+    painter.drawPixmap(layer.width() - m_xMargin - pix.width(), m_yMargin, pix);
     painter.end();
-
 }
 
 void SlideShowGL::printComments(QImage& layer)
@@ -644,8 +610,14 @@ void SlideShowGL::printComments(QImage& layer)
 
         int commentsLinesLengthLocal = m_sharedData->commentsLinesLength;
 
-        for ( currIndex = commentsIndex; currIndex < (uint) comments.length() && !breakLine; currIndex++ )
-            if ( comments[currIndex] == QChar('\n') || comments[currIndex].isSpace() ) breakLine = true;
+        for (currIndex = commentsIndex; currIndex < (uint) comments.length() && !breakLine; ++currIndex)
+        {
+            if (comments[currIndex] == QChar('\n') || comments[currIndex].isSpace())
+            {
+                breakLine = true;
+            }
+
+        }
 
         if (commentsLinesLengthLocal <= (int)((currIndex - commentsIndex)))
             commentsLinesLengthLocal = (currIndex - commentsIndex);
@@ -653,8 +625,7 @@ void SlideShowGL::printComments(QImage& layer)
         breakLine = false;
 
         for ( currIndex = commentsIndex; currIndex <= commentsIndex + commentsLinesLengthLocal &&
-                currIndex < (uint) comments.length() &&
-                !breakLine; currIndex++ )
+                currIndex < (uint) comments.length() && !breakLine; ++currIndex )
         {
             breakLine = (comments[currIndex] == QChar('\n')) ? true : false;
 
@@ -667,7 +638,7 @@ void SlideShowGL::printComments(QImage& layer)
         commentsIndex = currIndex; // The line is ended
 
         if ( commentsIndex != (uint) comments.length() )
-            while ( !newLine.endsWith(" ") )
+            while ( !newLine.endsWith(' ') )
             {
                 newLine.truncate(newLine.length() - 1);
                 commentsIndex--;
@@ -676,45 +647,25 @@ void SlideShowGL::printComments(QImage& layer)
         commentsByLines.prepend(newLine.trimmed());
     }
 
-    QFontMetrics fm(*m_sharedData->captionFont);
-
     yPos += int(2.0 * m_sharedData->captionFont->pointSize());
 
+    QFont  font(*m_sharedData->captionFont);
+    QColor fgColor(m_sharedData->commentsFontColor);
+    QColor bgColor(m_sharedData->commentsBgColor);
+    bool   transBg = m_sharedData->transparentBg;
+
     for ( int lineNumber = 0; lineNumber < (int)commentsByLines.count(); lineNumber++ )
     {
-
-        QRect rect = fm.boundingRect(commentsByLines[lineNumber]);
-        rect.adjust( 0, 0, 2, 2 );
-
-        QPixmap pix(rect.width(), rect.height());
-
-        if ( m_sharedData->transparentBg ) pix.fill(Qt::transparent);
-        else pix.fill(QColor(m_sharedData->commentsFontColor));
-
-        QPainter p(&pix);
-
-        p.setPen(QColor(m_sharedData->commentsFontColor));
-
-        p.setFont(*m_sharedData->captionFont);
-
-        p.drawText(1, m_sharedData->captionFont->pointSize() + 0 , commentsByLines[lineNumber]);
-
-        p.end();
+        QPixmap pix = generateCustomOutlinedTextPixmap(commentsByLines[lineNumber],
+                                                       font, fgColor, bgColor, transBg);
 
         QPainter painter;
-
         painter.begin(&layer);
 
-        QRect target = QRect(m_xMargin, m_height - rect.height() - yPos, rect.width(), rect.height());
-
-        QRect source = pix.rect();
-
-        painter.drawPixmap(target, pix, source);
-
+        painter.drawPixmap(m_xMargin, layer.height() - pix.height() - yPos, pix);
         painter.end();
 
-        yPos += int(rect.height() + m_height / 400);
-
+        yPos += int(pix.height() + m_height / 400);
     }
 }
 
@@ -785,7 +736,6 @@ void SlideShowGL::showEndOfShow()
     }
 
     glEnd();
-
 }
 
 void SlideShowGL::slotTimeOut()
@@ -1153,7 +1103,7 @@ void SlideShowGL::effectInOut()
 
     if (m_i == 0)
     {
-        m_dir = 1 + (int)((4.0 * rand() / (RAND_MAX + 1.0)));
+        m_dir = 1 + (int) ((4.0 * rand() / (RAND_MAX + 1.0)));
     }
 
     int a;
@@ -1162,12 +1112,12 @@ void SlideShowGL::effectInOut()
 
     if (m_i <= 50)
     {
-        a   = (m_curr == 0) ? 1 : 0;
+        a = (m_curr == 0) ? 1 : 0;
         out = 1;
     }
     else
     {
-        a   = m_curr;
+        a = m_curr;
         out = 0;
     }
 
@@ -1178,8 +1128,8 @@ void SlideShowGL::effectInOut()
     float t = out ? 1.0 / 50.0 * (50.0 - m_i) : 1.0 / 50.0 * (m_i - 50.0);
     glScalef(t, t, 1.0);
     t = 1.0 - t;
-glTranslatef((m_dir % 2 == 0) ? ((m_dir == 2) ? 1 : -1) * t : 0.0,
-             (m_dir % 2 == 1) ? ((m_dir == 1) ? 1 : -1) * t : 0.0,
+    glTranslatef((m_dir % 2 == 0) ? ((m_dir == 2) ? 1 : -1) * t : 0.0,
+                 (m_dir % 2 == 1) ? ((m_dir == 1) ? 1 : -1) * t : 0.0,
                  0.0);
 
     glBindTexture(GL_TEXTURE_2D, ta);
@@ -1346,9 +1296,9 @@ void SlideShowGL::effectFlutter()
         float float_x, float_y, float_xb, float_yb;
         int x, y;
 
-        for (x = 0; x < 39; x++)
+        for (x = 0; x < 39; ++x)
         {
-            for (y = 0; y < 39; y++)
+            for (y = 0; y < 39; ++y)
             {
                 float_x = (float) x / 40.0f;
                 float_y = (float) y / 40.0f;
@@ -1379,11 +1329,11 @@ void SlideShowGL::effectFlutter()
         float hold;
         int x, y;
 
-        for (y = 0; y < 40; y++)
+        for (y = 0; y < 40; ++y)
         {
             hold = m_points[0][y][2];
 
-            for (x = 0; x < 39; x++)
+            for (x = 0; x < 39; ++x)
             {
                 m_points[x][y][2] = m_points[x + 1][y][2];
             }
@@ -1427,21 +1377,15 @@ void SlideShowGL::effectCube()
 
     glLoadIdentity();
 
-    float PI = 4.0 * atan(1.0);
-
+    float PI    = 4.0 * atan(1.0);
     float znear = 3.0;
-
     float theta = 2.0 * atan2((float)2.0 / (float)2.0, (float)znear);
-
-    theta = theta * 180.0 / PI;
+    theta       = theta * 180.0 / PI;
 
     glFrustum(-1.0, 1.0, -1.0, 1.0, znear - 0.01, 10.0);
 
-
     static float xrot;
-
     static float yrot;
-
     static float zrot;
 
     if (m_i == 0)
@@ -1648,4 +1592,60 @@ void SlideShowGL::slotClose()
     close();
 }
 
+QPixmap SlideShowGL::generateOutlinedTextPixmap(const QString& text)
+{
+    QFont fn(font());
+    fn.setPointSize(fn.pointSize());
+    fn.setBold(true);
+
+    return generateOutlinedTextPixmap(text, fn);
+}
+
+QPixmap SlideShowGL::generateOutlinedTextPixmap(const QString& text, QFont& fn)
+{
+    QColor fgColor(Qt::white);
+    QColor bgColor(Qt::black);
+    return generateCustomOutlinedTextPixmap(text, fn, fgColor, bgColor, true);
+}
+
+QPixmap SlideShowGL::generateCustomOutlinedTextPixmap(const QString& text, QFont& fn,
+                                                      QColor& fgColor, QColor& bgColor,
+                                                      bool transBg)
+{
+    QFontMetrics fm(fn);
+    QRect rect = fm.boundingRect(text);
+    rect.adjust( 0, 0, 2, 2 );
+
+    QPixmap pix(rect.width(), rect.height());
+
+    if (transBg)
+        pix.fill(Qt::transparent);
+    else
+        pix.fill(bgColor);
+
+    QPainter p(&pix);
+    p.setRenderHint(QPainter::Antialiasing, true);
+    p.setBrush(QBrush());
+    p.setPen(QPen());
+
+    // draw outline
+    QPainterPath path;
+    path.addText(1, fn.pointSize() +1, fn, text);
+
+    QPainterPathStroker stroker;
+    stroker.setWidth(2);
+    stroker.setCapStyle(Qt::RoundCap);
+    stroker.setJoinStyle(Qt::RoundJoin);
+    QPainterPath outline = stroker.createStroke(path);
+
+    if (transBg)
+        p.fillPath(outline, Qt::black);
+    p.fillPath(path,    QBrush(fgColor));
+
+    p.setRenderHint(QPainter::Antialiasing, false);
+    p.end();
+
+    return pix;
+}
+
 }  // namespace KIPIAdvancedSlideshowPlugin
