@@ -6,9 +6,9 @@
  * Date        : 2004-01-19
  * Description : a kipi plugin to slide images.
  *
- * Copyright (C) 2004 by Renchi Raju <renchi@pooh.tam.uiuc.edu>
+ * Copyright (C) 2004      by Renchi Raju <renchi@pooh.tam.uiuc.edu>
  * Copyright (C) 2006-2009 by Valerio Fuoglio <valerio.fuoglio@gmail.com>
- * Copyright (C) 2009 by Andi Clemens <andi dot clemens at gmx dot net>
+ * Copyright (C) 2009      by Andi Clemens <andi dot clemens at gmx dot net>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -31,15 +31,15 @@
 
 // Qt includes
 
+#include <QGLWidget>
+#include <QKeyEvent>
 #include <QList>
-#include <QStringList>
+#include <QMap>
+#include <QMouseEvent>
 #include <QPair>
 #include <QString>
-#include <QMap>
+#include <QStringList>
 #include <QWheelEvent>
-#include <QMouseEvent>
-#include <QKeyEvent>
-#include <QGLWidget>
 
 // KDE includes
 
@@ -47,11 +47,13 @@
 
 // Local includes
 
-#include "slideshowloader.h"
-#include "slideplaybackwidget.h"
-#include "playbackwidget.h"
 #include "common.h"
+#include "playbackwidget.h"
+#include "slideplaybackwidget.h"
+#include "slideshowloader.h"
 
+class QColor;
+class QFont;
 class QTimer;
 
 namespace KIPIAdvancedSlideshowPlugin
@@ -89,6 +91,12 @@ private:
 
     typedef void (SlideShowGL::*EffectMethod)();
 
+    QPixmap       generateOutlinedTextPixmap(const QString& text);
+    QPixmap       generateOutlinedTextPixmap(const QString& text, QFont& fn);
+    QPixmap       generateCustomOutlinedTextPixmap(const QString& text,
+                                                   QFont& fn, QColor& fgColor, QColor& bgColor,
+                                                   bool transBg = true);
+
     void          paintTexture();
     void          advanceFrame();
     void          previousFrame();
@@ -110,7 +118,6 @@ private:
     void          effectFlutter();
     void          effectCube();
 
-
 private Q_SLOTS:
 
     void slotTimeOut();
