@@ -6,7 +6,7 @@
  * Date        : 2007-11-14
  * Description : a kipi plugin to slide images.
  *
- * Copyright (C) 2007-2008 by Valerio Fuoglio <valerio dot fuoglio at gmail dot com>
+ * Copyright (C) 2007-2009 by Valerio Fuoglio <valerio dot fuoglio at gmail dot com>
  *
  * Parts of this code are based on
  * smoothslidesaver by Carsten Weinhold <carsten dot weinhold at gmx dot de>
@@ -37,7 +37,7 @@
 
 // Qt includes
 
-#include <Q3ValueList>
+#include <QList>
 #include <QKeyEvent>
 #include <QMap>
 #include <QMouseEvent>
@@ -140,7 +140,7 @@ class SlideShowKB : public QGLWidget
 
 public:
 
-    SlideShowKB(const Q3ValueList<QPair<QString, int> >& fileList,
+    SlideShowKB(const QList<QPair<QString, int> >& fileList,
                 const QStringList& commentsList, SharedData* sharedData);
 
     ~SlideShowKB();
