@@ -7,7 +7,7 @@
  * Description : a kipi plugin to slide images.
  *
  * Copyright (C) 2007-2009 by Valerio Fuoglio <valerio dot fuoglio at gmail dot com>
- * Copyright (C) 2009 by Andi Clemens <andi dot clemens at gmx dot net>
+ * Copyright (C) 2009      by Andi Clemens <andi dot clemens at gmx dot net>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -55,7 +55,6 @@ LoadThread::LoadThread(LoadedImages* loadedImages, QMutex* imageLock, const KUrl
                        const int angle, int width, int height)
           : QThread()
 {
-
     m_path          = path;
     m_angle         = angle;
     m_swidth        = width;
@@ -160,7 +159,9 @@ SlideShowLoader::~SlideShowLoader()
 
     for (it = m_loadingThreads->begin(); it != m_loadingThreads->end(); ++it)
     {
-        it.value()->wait();
+        // better check for a valid pointer here
+        if (it.value())
+            it.value()->wait();
         delete it.value();
         it = m_loadingThreads->erase(it);
     }
@@ -187,6 +188,11 @@ void SlideShowLoader::next()
     m_threadLock->lock();
     m_imageLock->lock();
 
+    LoadThread* oldThread = m_loadingThreads->value(m_pathList[victim].first);
+    if (oldThread)
+        oldThread->wait();
+    delete oldThread;
+
     m_loadingThreads->remove(m_pathList[victim].first);
     m_loadedImages->remove(m_pathList[victim].first);
 
@@ -222,6 +228,11 @@ void SlideShowLoader::prev()
     m_threadLock->lock();
     m_imageLock->lock();
 
+    LoadThread* oldThread = m_loadingThreads->value(m_pathList[victim].first);
+    if (oldThread)
+        oldThread->wait();
+    delete oldThread;
+
     m_loadingThreads->remove(m_pathList[victim].first);
     m_loadedImages->remove(m_pathList[victim].first);
 
