@@ -54,6 +54,7 @@
 
 // Local includes
 
+#include "batchprocessimageslist.h"
 #include "convertoptionsdialog.h"
 #include "dialogutils.h"
 #include "kpaboutdata.h"
@@ -71,8 +72,8 @@ ConvertImagesDialog::ConvertImagesDialog( KUrl::List urlList, KIPI::Interface* i
     m_about = new KIPIPlugins::KPAboutData(ki18n("Batch convert images"),
                                            QByteArray(),
                                            KAboutData::License_GPL,
-                                           ki18n("A Kipi plugin for batch converting images\n"
-                                                     "This plugin uses the \"convert\" program from \"ImageMagick\" package."),
+                                           ki18n("A Kipi plugin for batch converting images.\n"
+                                                     "This plugin uses the \"convert\" program from the \"ImageMagick\" package."),
                                            ki18n("(c) 2003-2009, Gilles Caulier\n"
                                                  "(c) 2007-2009, Aurélien Gateau"));
 
@@ -85,7 +86,7 @@ ConvertImagesDialog::ConvertImagesDialog( KUrl::List urlList, KIPI::Interface* i
     DialogUtils::setupHelpButton(this, m_about);
     //---------------------------------------------
 
-    groupBox1->setTitle( i18n("Image Conversion Options") );
+    setOptionBoxTitle( i18n("Image Conversion Options") );
 
     m_labelType->setText( i18n("Format:") );
 
@@ -97,7 +98,7 @@ ConvertImagesDialog::ConvertImagesDialog( KUrl::List urlList, KIPI::Interface* i
     m_Type->insertItem("TGA");
     m_Type->insertItem("EPS");
     m_Type->setCurrentText("JPEG");
-    whatsThis = i18n("<p>Select here the target image file format.</p>");
+    QString whatsThis = i18n("<p>Select here the target image file format.</p>");
     whatsThis = whatsThis + i18n("<p><b>JPEG</b>: The Joint Photographic Experts Group's file format is a "
                                  "good Web file format but it uses lossy data compression.</p>"
                                  "<p><b>PNG</b>: the Portable Network Graphics format is an extensible file "
@@ -114,7 +115,7 @@ ConvertImagesDialog::ConvertImagesDialog( KUrl::List urlList, KIPI::Interface* i
     whatsThis = whatsThis + i18n("<p><b>PPM</b>: the Portable Pixel Map file format is used as an "
                                  "intermediate format for storing color bitmap information. PPM files "
                                  "may be either binary or ASCII and store pixel values up to 24 bits in size. "
-                                 "This format generate the largest-sized text files to encode images without "
+                                 "This format generates the largest-sized text files to encode images without "
                                  "losing quality.</p>");
     whatsThis = whatsThis + i18n("<p><b>BMP</b>: the BitMaP file format is a popular image format from Win32 "
                                  "environment. It efficiently stores mapped or unmapped RGB graphics data with "
@@ -133,8 +134,7 @@ ConvertImagesDialog::ConvertImagesDialog( KUrl::List urlList, KIPI::Interface* i
 
     m_Type->setWhatsThis(whatsThis );
 
-    m_previewButton->hide();
-    m_smallPreview->hide();
+    setPreviewOptionsVisible(false);
 
     //---------------------------------------------
 
@@ -215,13 +215,7 @@ void ConvertImagesDialog::readSettings(void)
     m_TIFFCompressionAlgo = group.readEntry("TIFFCompressionAlgo", i18n("None"));
     m_TGACompressionAlgo = group.readEntry("TGACompressionAlgo", i18n("None"));
 
-    m_overWriteMode->setCurrentIndex(group.readEntry("OverWriteMode", 2));  // 'Rename' per default...
-
-    if (group.readEntry("RemoveOriginal", "false") == "true")
-        m_removeOriginal->setChecked( true );
-    else
-        m_removeOriginal->setChecked( false );
-
+    readCommonSettings(group);
 }
 
 void ConvertImagesDialog::saveSettings(void)
@@ -237,9 +231,7 @@ void ConvertImagesDialog::saveSettings(void)
     group.writeEntry("TIFFCompressionAlgo", m_TIFFCompressionAlgo);
     group.writeEntry("TGACompressionAlgo", m_TGACompressionAlgo);
 
-    group.writeEntry("OverWriteMode", m_overWriteMode->currentItem());
-    group.writeEntry("RemoveOriginal", m_removeOriginal->isChecked());
-
+    saveCommonSettings(group);
 }
 
 void ConvertImagesDialog::initProcess(KProcess* proc, BatchProcessImagesItem *item,
@@ -247,12 +239,6 @@ void ConvertImagesDialog::initProcess(KProcess* proc, BatchProcessImagesItem *it
 {
     *proc << "convert";
 
-    if ( previewMode && m_smallPreview->isChecked() )    // Preview mode and small preview enabled !
-    {
-       *m_PreviewProc << "-crop" << "300x300+0+0";
-       m_previewOutput.append( " -crop 300x300+0+0 ");
-    }
-
     if (m_Type->currentItem() == 0) // JPEG
     {
        if (m_compressLossLess == true)
@@ -321,11 +307,11 @@ void ConvertImagesDialog::processDone()
         if (item)
         {
             QString src = item->pathSrc();
-            QString tgt = m_destinationURL->url().path() + "/" + item->nameDest();
+            QString tgt = destinationUrl().path() + "/" + item->nameDest();
             QFileInfo fi(tgt);
 
-            kDebug() << src << endl;
-            kDebug() << tgt << fi.size()<< endl;
+            kDebug(51000) << src ;
+            kDebug(51000) << tgt << fi.size();
 
             KExiv2Iface::KExiv2 metaSrc(src);
 
