@@ -23,23 +23,22 @@
 #include "filteroptionsdialog.h"
 #include "filteroptionsdialog.moc"
 
-// Include files for Qt
+// Qt includes
 
-#include <q3vbox.h>
-#include <q3groupbox.h>
-#include <Q3VBoxLayout>
-#include <qlayout.h>
-#include <qwidget.h>
-#include <qlabel.h>
-#include <qpushbutton.h>
-#include <qcombobox.h>
-#include <qcolor.h>
+#include <QColor>
+#include <QGroupBox>
+#include <QLabel>
+#include <QLayout>
+#include <QPushButton>
+#include <QVBoxLayout>
+#include <QWidget>
 
-// Include files for KDE
+// KDE includes
 
+#include <kcolorbutton.h>
+#include <kcombobox.h>
 #include <klocale.h>
 #include <knuminput.h>
-#include <kcolorbutton.h>
 
 namespace KIPIBatchProcessImagesPlugin
 {
@@ -53,22 +52,22 @@ FilterOptionsDialog::FilterOptionsDialog(QWidget *parent, int FilterType)
     setDefaultButton(Ok);
     QWidget* box = new QWidget( this );
     setMainWidget(box);
-    Q3VBoxLayout *dvlay = new Q3VBoxLayout( box, 10, spacingHint() );
+    QVBoxLayout *dvlay = new QVBoxLayout( box, 10, spacingHint() );
     QString whatsThis;
 
     if (FilterType == 0) // Add noise
        {
        QLabel *m_label_noiseType = new QLabel (i18n("Noise algorithm:"), box);
        dvlay->addWidget( m_label_noiseType );
-       m_noiseType = new QComboBox( false, box );
+       m_noiseType = new KComboBox( false, box );
        m_noiseType->insertItem(i18n("Uniform"));
        m_noiseType->insertItem(i18n("Gaussian"));
        m_noiseType->insertItem(i18n("Multiplicative"));
        m_noiseType->insertItem(i18n("Impulse"));
        m_noiseType->insertItem(i18n("Laplacian"));
        m_noiseType->insertItem(i18n("Poisson"));
-       m_noiseType->setWhatsThis(i18n("<p>Select here the algorithm method which will used "
-                                          "to add random noise to the images.") );
+       m_noiseType->setWhatsThis(i18n("Select here the algorithm method which will used "
+                                      "to add random noise to the images.") );
        m_label_noiseType->setBuddy( m_noiseType );
        dvlay->addWidget( m_noiseType );
        }
@@ -80,10 +79,10 @@ FilterOptionsDialog::FilterOptionsDialog(QWidget *parent, int FilterType)
        m_blurRadius = new KIntNumInput(3, box);
        m_blurRadius->setRange(0, 20);
        m_blurRadius->setSliderEnabled(true);
-       m_blurRadius->setWhatsThis(i18n("<p>Select here the blur radius of the Gaussian, in pixels, "
-                                           "not counting the center pixel. For reasonable results, the "
-                                           "radius should be larger than deviation. If you use a radius of 0 "
-                                           "the blur operations selects a suitable radius.") );
+       m_blurRadius->setWhatsThis(i18n("Select here the blur radius of the Gaussian, in pixels, "
+                                       "not counting the center pixel. For reasonable results, the "
+                                       "radius should be larger than deviation. If you use a radius of 0 "
+                                       "the blur operations selects a suitable radius.") );
        m_label_blurRadius->setBuddy( m_blurRadius );
        dvlay->addWidget( m_blurRadius );
 
@@ -92,8 +91,8 @@ FilterOptionsDialog::FilterOptionsDialog(QWidget *parent, int FilterType)
        m_blurDeviation = new KIntNumInput(1, box);
        m_blurDeviation->setRange(0, 20);
        m_blurDeviation->setSliderEnabled(true);
-       m_blurDeviation->setWhatsThis(i18n("<p>Select here the standard deviation of the blur Gaussian, "
-                                              "in pixels.") );
+       m_blurDeviation->setWhatsThis(i18n("Select here the standard deviation of the blur Gaussian, "
+                                          "in pixels.") );
        m_label_blurDeviation->setBuddy( m_blurDeviation );
        dvlay->addWidget( m_blurDeviation );
        }
@@ -105,10 +104,10 @@ FilterOptionsDialog::FilterOptionsDialog(QWidget *parent, int FilterType)
        m_medianRadius = new KIntNumInput(3, box);
        m_medianRadius->setRange(0, 20);
        m_medianRadius->setSliderEnabled(true);
-       m_medianRadius->setWhatsThis(i18n("<p>Select here the median radius of the pixel neighborhood. "
-                                             "The algorithm applies a digital filter that improves the quality "
-                                             "of noisy images. Each pixel is replaced by the median in a "
-                                             "set of neighboring pixels as defined by the radius.") );
+       m_medianRadius->setWhatsThis(i18n("Select here the median radius of the pixel neighborhood. "
+                                         "The algorithm applies a digital filter that improves the quality "
+                                         "of noisy images. Each pixel is replaced by the median in a "
+                                         "set of neighboring pixels as defined by the radius.") );
        m_label_medianRadius->setBuddy( m_medianRadius );
        dvlay->addWidget( m_medianRadius );
        }
@@ -121,12 +120,12 @@ FilterOptionsDialog::FilterOptionsDialog(QWidget *parent, int FilterType)
        m_noiseRadius = new KIntNumInput(3, box);
        m_noiseRadius->setRange(0, 20);
        m_noiseRadius->setSliderEnabled(true);
-       m_noiseRadius->setWhatsThis(i18n("<p>Select here the noise reduction radius value, in pixels. "
-                                            "The algorithm smooths the contours of an image while still "
-                                            "preserving edge information. The algorithm works by replacing "
-                                            "each pixel with its neighbor closest in value. A neighbor is "
-                                            "defined by the radius. If you use a radius of 0 the algorithm "
-                                            "selects a suitable radius.") );
+       m_noiseRadius->setWhatsThis(i18n("Select here the noise reduction radius value, in pixels. "
+                                        "The algorithm smooths the contours of an image while still "
+                                        "preserving edge information. The algorithm works by replacing "
+                                        "each pixel with its neighbor closest in value. A neighbor is "
+                                        "defined by the radius. If you use a radius of 0 the algorithm "
+                                        "selects a suitable radius.") );
        m_label_noiseRadius->setBuddy( m_noiseRadius );
        dvlay->addWidget( m_noiseRadius );
        }
@@ -138,11 +137,11 @@ FilterOptionsDialog::FilterOptionsDialog(QWidget *parent, int FilterType)
        m_sharpenRadius = new KIntNumInput(3, box);
        m_sharpenRadius->setRange(0, 20);
        m_sharpenRadius->setSliderEnabled(true);
-       m_sharpenRadius->setWhatsThis(i18n("<p>Select here the radius of the sharpen Gaussian, in "
-                                              "pixels, not counting the center pixel. For reasonable "
-                                              "results, the radius should be larger than deviation. "
-                                              "If you use a radius of 0 the sharpen operation selects a "
-                                              "suitable radius.") );
+       m_sharpenRadius->setWhatsThis(i18n("Select here the radius of the sharpen Gaussian, in "
+                                          "pixels, not counting the center pixel. For reasonable "
+                                          "results, the radius should be larger than deviation. "
+                                          "If you use a radius of 0 the sharpen operation selects a "
+                                          "suitable radius."));
        m_label_sharpenRadius->setBuddy( m_sharpenRadius );
        dvlay->addWidget( m_sharpenRadius );
 
@@ -151,8 +150,8 @@ FilterOptionsDialog::FilterOptionsDialog(QWidget *parent, int FilterType)
        m_sharpenDeviation = new KIntNumInput(1, box);
        m_sharpenDeviation->setRange(0, 20);
        m_sharpenDeviation->setSliderEnabled(true);
-       m_sharpenDeviation->setWhatsThis(i18n("<p>Select here the sharpen deviation value of the "
-                                                 "Laplacian in pixels.") );
+       m_sharpenDeviation->setWhatsThis(i18n("Select here the sharpen deviation value of the "
+                                             "Laplacian in pixels.") );
        m_label_sharpenDeviation->setBuddy( m_sharpenDeviation );
        dvlay->addWidget( m_sharpenDeviation );
        }
@@ -164,12 +163,12 @@ FilterOptionsDialog::FilterOptionsDialog(QWidget *parent, int FilterType)
        m_unsharpenRadius = new KIntNumInput(3, box);
        m_unsharpenRadius->setRange(0, 20);
        m_unsharpenRadius->setSliderEnabled(true);
-       m_unsharpenRadius->setWhatsThis(i18n("<p>Select here the radius of the unsharpen Gaussian, "
-                                                "in pixels, not counting the center pixel. The algorithm "
-                                                "convolve the image with a Gaussian operator of the given "
-                                                "radius and standard deviation. For reasonable results, "
-                                                "radius should be larger than sigma. If you use a radius of 0 "
-                                                "the algorithm selects a suitable radius.") );
+       m_unsharpenRadius->setWhatsThis(i18n("Select here the radius of the unsharpen Gaussian, "
+                                            "in pixels, not counting the center pixel. The algorithm "
+                                            "convolve the image with a Gaussian operator of the given "
+                                            "radius and standard deviation. For reasonable results, "
+                                            "radius should be larger than sigma. If you use a radius of 0 "
+                                            "the algorithm selects a suitable radius.") );
        m_label_unsharpenRadius->setBuddy( m_unsharpenRadius );
        dvlay->addWidget( m_unsharpenRadius );
 
@@ -178,8 +177,8 @@ FilterOptionsDialog::FilterOptionsDialog(QWidget *parent, int FilterType)
        m_unsharpenDeviation = new KIntNumInput(1, box);
        m_unsharpenDeviation->setRange(0, 20);
        m_unsharpenDeviation->setSliderEnabled(true);
-       m_unsharpenDeviation->setWhatsThis(i18n("<p>Select here the unsharpen deviation value of the "
-                                                   "Gaussian, in pixels.") );
+       m_unsharpenDeviation->setWhatsThis(i18n("Select here the unsharpen deviation value of the "
+                                               "Gaussian, in pixels.") );
        m_label_unsharpenDeviation->setBuddy( m_unsharpenDeviation );
        dvlay->addWidget( m_unsharpenDeviation );
 
@@ -188,8 +187,8 @@ FilterOptionsDialog::FilterOptionsDialog(QWidget *parent, int FilterType)
        m_unsharpenPercent = new KIntNumInput(3, box);
        m_unsharpenPercent->setRange(1, 100);
        m_unsharpenPercent->setSliderEnabled(true);
-       m_unsharpenPercent->setWhatsThis(i18n("<p>Select here the percentage difference between original "
-                                                 "and blurred image which should be added to original.") );
+       m_unsharpenPercent->setWhatsThis(i18n("Select here the percentage difference between original "
+                                             "and blurred image which should be added to original.") );
        m_label_unsharpenPercent->setBuddy( m_unsharpenPercent );
        dvlay->addWidget( m_unsharpenPercent );
 
@@ -198,9 +197,9 @@ FilterOptionsDialog::FilterOptionsDialog(QWidget *parent, int FilterType)
        m_unsharpenThreshold = new KIntNumInput(1, box);
        m_unsharpenThreshold->setRange(0, 20);
        m_unsharpenThreshold->setSliderEnabled(true);
-       m_unsharpenThreshold->setWhatsThis(i18n("<p>Select here the unsharpen threshold value, in "
-                                                   "pixels, needed to apply the diffence amount."));
-       m_label_unsharpenThreshold->setBuddy( m_unsharpenThreshold );
+       m_unsharpenThreshold->setWhatsThis(i18n("Select here the unsharpen threshold value, in "
+                                               "pixels, needed to apply the difference amount."));
+       m_label_unsharpenThreshold->setBuddy(m_unsharpenThreshold);
        dvlay->addWidget( m_unsharpenThreshold );
        }
 }
@@ -209,4 +208,4 @@ FilterOptionsDialog::~FilterOptionsDialog()
 {
 }
 
-}  // NameSpace KIPIBatchProcessImagesPlugin
+}  // namespace KIPIBatchProcessImagesPlugin
