@@ -63,8 +63,8 @@ RecompressImagesDialog::RecompressImagesDialog( KUrl::List urlList, KIPI::Interf
     m_about = new KIPIPlugins::KPAboutData(ki18n("Batch recompress images"),
                                            QByteArray(),
                                            KAboutData::License_GPL,
-                                           ki18n("A Kipi plugin to batch recompress images\n"
-                                                     "This plugin uses the \"convert\" program from \"ImageMagick\" package."),
+                                           ki18n("A Kipi plugin to batch recompress images.\n"
+                                                     "This plugin uses the \"convert\" program from the \"ImageMagick\" package."),
                                            ki18n("(c) 2003-2009, Gilles Caulier\n"
                                                  "(c) 2007-2009, Aurélien Gateau"));
 
@@ -81,12 +81,11 @@ RecompressImagesDialog::RecompressImagesDialog( KUrl::List urlList, KIPI::Interf
 
     //---------------------------------------------
 
-    groupBox1->setTitle( i18n("Image Recompression Options") );
+    setOptionBoxTitle( i18n("Image Recompression Options") );
 
     m_labelType->hide();
     m_Type->hide();
-    m_previewButton->hide();
-    m_smallPreview->hide();
+    setPreviewOptionsVisible(false);
 
     //---------------------------------------------
 
@@ -144,13 +143,7 @@ void RecompressImagesDialog::readSettings(void)
     m_TIFFCompressionAlgo = group.readEntry("TIFFCompressionAlgo", i18n("None"));
     m_TGACompressionAlgo = group.readEntry("TGACompressionAlgo", i18n("None"));
 
-    m_overWriteMode->setCurrentIndex(group.readEntry("OverWriteMode", 2));  // 'Rename' per default...
-
-    if (group.readEntry("RemoveOriginal", "false") == "true")
-        m_removeOriginal->setChecked( true );
-    else
-        m_removeOriginal->setChecked( false );
-
+    readCommonSettings(group);
 }
 
 void RecompressImagesDialog::saveSettings(void)
@@ -166,10 +159,7 @@ void RecompressImagesDialog::saveSettings(void)
     group.writeEntry("TIFFCompressionAlgo", m_TIFFCompressionAlgo);
     group.writeEntry("TGACompressionAlgo", m_TGACompressionAlgo);
 
-    group.writeEntry("OverWriteMode", m_overWriteMode->currentItem());
-    group.writeEntry("RemoveOriginal", m_removeOriginal->isChecked());
-
-
+    saveCommonSettings(group);
 }
 
 void RecompressImagesDialog::initProcess(KProcess* proc, BatchProcessImagesItem *item,
@@ -177,12 +167,6 @@ void RecompressImagesDialog::initProcess(KProcess* proc, BatchProcessImagesItem
 {
     *proc << "convert";
 
-    if ( previewMode && m_smallPreview->isChecked() )    // Preview mode and small preview enabled !
-       {
-       *m_PreviewProc << "-crop" << "300x300+0+0";
-       m_previewOutput.append( " -crop 300x300+0+0 ");
-       }
-
     QString imageExt = item->nameSrc().section('.', -1 );
 
     if (imageExt == "JPEG" || imageExt == "jpeg" || imageExt == "JPG" || imageExt == "jpg")
