@@ -65,8 +65,8 @@ ResizeImagesDialog::ResizeImagesDialog( KUrl::List urlList, KIPI::Interface* int
     m_about = new KIPIPlugins::KPAboutData(ki18n("Batch resize images"),
                                            QByteArray(),
                                            KAboutData::License_GPL,
-                                           ki18n("A Kipi plugin to batch-resize images\n"
-                                                     "This plugin uses the \"convert\" program from \"ImageMagick\" package."),
+                                           ki18n("A Kipi plugin to batch-resize images.\n"
+                                                     "This plugin uses the \"convert\" program from the \"ImageMagick\" package."),
                                            ki18n("(c) 2003-2009, Gilles Caulier\n"
                                                  "(c) 2007-2009, Aurélien Gateau"));
 
@@ -84,7 +84,7 @@ ResizeImagesDialog::ResizeImagesDialog( KUrl::List urlList, KIPI::Interface* int
 
     //---------------------------------------------
 
-    groupBox1->setTitle( i18n("Image Resizing Options") );
+    setOptionBoxTitle( i18n("Image Resizing Options") );
 
     m_labelType->setText( i18n("Type:") );
 
@@ -93,7 +93,7 @@ ResizeImagesDialog::ResizeImagesDialog( KUrl::List urlList, KIPI::Interface* int
     m_Type->insertItem(i18n("Non-Proportional"));       // 2
     m_Type->insertItem(i18n("Prepare to Print"));       // 3
     m_Type->setCurrentText(i18n("Proportional (1 dim.)"));
-    whatsThis = i18n("<p>Select here the image-resize type.</p>");
+    QString whatsThis = i18n("<p>Select here the image-resize type.</p>");
     whatsThis = whatsThis + i18n("<p><b>Proportional (1 dim.)</b>: standard auto-resizing using one dimension. "
                                  "The width or the height of the images will be automatically "
                                  "selected, depending on the images' orientations. "
@@ -110,8 +110,7 @@ ResizeImagesDialog::ResizeImagesDialog( KUrl::List urlList, KIPI::Interface* int
 
     m_Type->setWhatsThis(whatsThis );
 
-    m_previewButton->hide();
-    m_smallPreview->hide();
+    setPreviewOptionsVisible(false);
 
     //---------------------------------------------
 
@@ -246,12 +245,7 @@ void ResizeImagesDialog::readSettings(void)
     else
        m_customSettings = false;
 
-    m_overWriteMode->setCurrentIndex(group.readEntry("OverWriteMode", 2));  // 'Rename' per default...
-
-    if (group.readEntry("RemoveOriginal", "false") == "true")
-        m_removeOriginal->setChecked( true );
-    else
-        m_removeOriginal->setChecked( false );
+    readCommonSettings(group);
 }
 
 void ResizeImagesDialog::saveSettings(void)
@@ -282,10 +276,7 @@ void ResizeImagesDialog::saveSettings(void)
     group.writeEntry("FixedWidth", m_fixedWidth);
     group.writeEntry("FixedHeight", m_fixedHeight);
 
-    group.writeEntry("OverWriteMode", m_overWriteMode->currentItem());
-    group.writeEntry("RemoveOriginal", m_removeOriginal->isChecked());
-
-
+    saveCommonSettings(group);
 }
 
 void ResizeImagesDialog::initProcess(KProcess* proc, BatchProcessImagesItem *item,
