@@ -168,7 +168,7 @@ void CalWizard::slotPageSelected(KPageWidgetItem *current, KPageWidgetItem *befo
         QString month;
         QStringList printList;
         QDate d;
-        KGlobal::locale()->calendar()->setYMD(d, cSettings_->year(), 1, 1);
+        KGlobal::locale()->calendar()->setDate(d, cSettings_->year(), 1, 1);
         for (int i=1; i<=KGlobal::locale()->calendar()->monthsInYear(d); i++)
         {
             month = KGlobal::locale()->calendar()->monthName(i, cSettings_->year(), KCalendarSystem::LongName);
@@ -198,8 +198,12 @@ void CalWizard::slotPageSelected(KPageWidgetItem *current, KPageWidgetItem *befo
                         "calendar for<br/>the current year or a year in the "
                         "past.")+"</b>";
 
+	    KLocale tmpLocale(*KGlobal::locale());
+	    tmpLocale.setDateFormat("%Y");
+	    QString year_locale = tmpLocale.formatDate(d);
+
             wPrintLabel_->setText(i18n("Click Next to start Printing<br/><br/>"
-                    "Following months will be printed for year %1:<br/>", year)
+                    "Following months will be printed for year %1:<br/>", year_locale)
                     + printList.join(" - ") + extra);
             wPrintLabel_->setTextFormat(Qt::RichText);
 
