@@ -72,6 +72,7 @@ ImagesListViewItem::ImagesListViewItem(ImagesListView *view, const KUrl& url)
     setThumb(SmallIcon("image-x-generic", iconSize, KIconLoader::DisabledState));
     setUrl(url);
     setRating(-1);
+    setFlags(Qt::ItemIsEnabled|Qt::ItemIsDragEnabled|Qt::ItemIsSelectable);
 }
 
 ImagesListViewItem::~ImagesListViewItem()
@@ -174,10 +175,13 @@ void ImagesListView::setup(int iconSize)
 {
     m_iconSize = iconSize;
     setIconSize(QSize(m_iconSize, m_iconSize));
-    setSelectionMode(QAbstractItemView::ExtendedSelection);
+    setAlternatingRowColors(true);
+    setSelectionMode(QAbstractItemView::SingleSelection);
 
-    setAcceptDrops(true);
+    setDragEnabled(true);
     viewport()->setAcceptDrops(true);
+    setDragDropMode(QAbstractItemView::InternalMove);
+    setDragDropOverwriteMode(false);
     setDropIndicatorShown(true);
 
     setSortingEnabled(false);
@@ -242,18 +246,21 @@ void ImagesListView::setColumn(ColumnType column, const QString &label, bool ena
 
 void ImagesListView::dragEnterEvent(QDragEnterEvent *e)
 {
+    QTreeWidget::dragEnterEvent(e);
     if (e->mimeData()->hasUrls())
         e->acceptProposedAction();
 }
 
 void ImagesListView::dragMoveEvent(QDragMoveEvent *e)
 {
+    QTreeWidget::dragMoveEvent(e);
     if (e->mimeData()->hasUrls())
         e->acceptProposedAction();
 }
 
 void ImagesListView::dropEvent(QDropEvent *e)
 {
+    QTreeWidget::dropEvent(e);
     QList<QUrl> list = e->mimeData()->urls();
     KUrl::List urls;
 
@@ -264,8 +271,6 @@ void ImagesListView::dropEvent(QDropEvent *e)
             urls.append(KUrl(url));
     }
 
-    e->acceptProposedAction();
-
     if (!urls.isEmpty())
         emit addedDropedItems(urls);
 }
@@ -281,84 +286,96 @@ KIPI::Interface* ImagesListView::iface() const
 
 // ---------------------------------------------------------------------------
 
+CtrlButton::CtrlButton(const QIcon& icon, QWidget* parent)
+          : QPushButton(parent)
+{
+
+    const int btnSize = 32;
+
+    setMinimumSize(btnSize, btnSize);
+    setMaximumSize(btnSize, btnSize);
+    setIcon(icon);
+}
+
+CtrlButton::~CtrlButton()
+{
+}
+
+// ---------------------------------------------------------------------------
+
 class ImagesListPriv
 {
 public:
 
     ImagesListPriv()
     {
-        listView        = 0;
-        iface           = 0;
-        addButton       = 0;
-        removeButton    = 0;
-        plainPage       = 0;
-        iconSize        = DEFAULTSIZE;
+        listView              = 0;
+        iface                 = 0;
+
+        addButton             = 0;
+        removeButton          = 0;
+        moveUpButton          = 0;
+        moveDownButton        = 0;
+        clearButton           = 0;
+        loadButton            = 0;
+        saveButton            = 0;
+
+        iconSize              = DEFAULTSIZE;
+        allowRAW              = true;
+        controlButtonsEnabled = true;
     }
 
-    bool                allowRAW;
-    int                 iconSize;
+    bool            allowRAW;
+    bool            controlButtonsEnabled;
+    int             iconSize;
 
-    QPushButton*        addButton;
-    QPushButton*        removeButton;
+    CtrlButton*     addButton;
+    CtrlButton*     removeButton;
+    CtrlButton*     moveUpButton;
+    CtrlButton*     moveDownButton;
+    CtrlButton*     clearButton;
+    CtrlButton*     loadButton;
+    CtrlButton*     saveButton;
 
-    QWidget*            plainPage;
-
-    ImagesListView*     listView;
-    Interface*          iface;
+    ImagesListView* listView;
+    Interface*      iface;
 };
 
-ImagesList::ImagesList(Interface *iface, QWidget* parent,
-                       ControlButtonPlacement btnPlace, int iconSize)
-          : QWidget(parent),
-            d(new ImagesListPriv)
+ImagesList::ImagesList(Interface *iface, QWidget* parent, int iconSize)
+          : QWidget(parent), d(new ImagesListPriv)
 {
     d->iface    = iface;
-    d->allowRAW = true;  // default, use setAllowRAW() to change
 
     if (iconSize != -1)  // default = ICONSIZE
         setIconSize(iconSize);
 
     // --------------------------------------------------------
 
-    QGridLayout* mainLayout = new QGridLayout;
-    d->listView             = new ImagesListView(d->iconSize, this);
-    d->plainPage            = new QWidget(this);
-    d->plainPage->hide();
+    d->listView  = new ImagesListView(d->iconSize, this);
+    d->listView->setSelectionMode(QAbstractItemView::SingleSelection);
 
     // --------------------------------------------------------
 
-    d->addButton    = new QPushButton(this);
-    d->removeButton = new QPushButton(this);
+    d->addButton      = new CtrlButton(SmallIcon("list-add"), this);
+    d->removeButton   = new CtrlButton(SmallIcon("list-remove"), this);
+    d->moveUpButton   = new CtrlButton(SmallIcon("arrow-up"), this);
+    d->moveDownButton = new CtrlButton(SmallIcon("arrow-down"), this);
+    d->clearButton    = new CtrlButton(SmallIcon("edit-clear-list"), this);
+    d->loadButton     = new CtrlButton(SmallIcon("document-open"), this);
+    d->saveButton     = new CtrlButton(SmallIcon("document-save"), this);
 
-    d->addButton->setText(i18n("&Add"));
-    d->addButton->setIcon(SmallIcon("list-add"));
-    d->addButton->hide();
-
-    d->removeButton->setText(i18n("&Remove"));
-    d->removeButton->setIcon(SmallIcon("list-remove"));
-    d->removeButton->hide();
+    d->addButton->setToolTip(i18n("Add new images to the list"));
+    d->removeButton->setToolTip(i18n("Remove selected images from the list"));
+    d->moveUpButton->setToolTip(i18n("Move current selected image up in the list"));
+    d->moveDownButton->setToolTip(i18n("Move current selected image down in the list"));
+    d->clearButton->setToolTip(i18n("Clear the list."));
+    d->loadButton->setToolTip(i18n("Load a saved list."));
+    d->saveButton->setToolTip(i18n("Save the list."));
 
     // --------------------------------------------------------
 
-    mainLayout->addWidget(d->listView, 0, 0, 5, 5);
-    switch (btnPlace)
-    {
-        case ControlButtonsBelow:
-            mainLayout->addWidget(d->addButton,    5, 0, 1, 1);
-            mainLayout->addWidget(d->removeButton, 5, 1, 1, 1);
-            mainLayout->addWidget(d->plainPage,    5, 2, 1, 1);
-            break;
-        case ControlButtonsRight:
-            mainLayout->addWidget(d->addButton,    0, 5, 1, 1);
-            mainLayout->addWidget(d->removeButton, 1, 5, 1, 1);
-            mainLayout->addWidget(d->plainPage,    2, 5, 1, 1);
-            break;
-        case NoControlButtons:
-            break;
-    }
-    mainLayout->setMargin(KDialog::spacingHint());
-    mainLayout->setSpacing(KDialog::spacingHint());
-    setLayout(mainLayout);
+    setControlButtons(Add|Remove|MoveUp|MoveDown|Clear);      // add all buttons       (default)
+    setControlButtonsPlacement(ControlButtonsRight);          // buttons on the right  (default)
 
     // --------------------------------------------------------
 
@@ -371,20 +388,122 @@ ImagesList::ImagesList(Interface *iface, QWidget* parent,
     connect(d->listView, SIGNAL(signalItemClicked(QTreeWidgetItem*)),
             this, SIGNAL(signalItemClicked(QTreeWidgetItem*)));
 
+    connect(this, SIGNAL(signalImageListChanged()),
+            this, SLOT(slotImageListChanged()));
+
     // --------------------------------------------------------
 
-    if (btnPlace != NoControlButtons)
+    connect(d->addButton, SIGNAL(clicked()),
+            this, SLOT(slotAddItems()));
+
+    connect(d->removeButton, SIGNAL(clicked()),
+            this, SLOT(slotRemoveItems()));
+
+    connect(d->moveUpButton, SIGNAL(clicked()),
+            this, SLOT(slotMoveUpItems()));
+
+    connect(d->moveDownButton, SIGNAL(clicked()),
+            this, SLOT(slotMoveDownItems()));
+
+    connect(d->clearButton, SIGNAL(clicked()),
+            this, SLOT(slotClearItems()));
+
+    connect(d->loadButton, SIGNAL(clicked()),
+            this, SLOT(slotLoadItems()));
+
+    connect(d->saveButton, SIGNAL(clicked()),
+            this, SLOT(slotSaveItems()));
+
+    // --------------------------------------------------------
+
+    emit signalImageListChanged();
+}
+
+void ImagesList::enableControlButtons(bool enable)
+{
+    d->controlButtonsEnabled = enable;
+    slotImageListChanged();
+}
+
+void ImagesList::setControlButtonsPlacement(ControlButtonPlacement placement)
+{
+    delete layout();
+
+    QGridLayout* mainLayout = new QGridLayout;
+    mainLayout->addWidget(d->listView, 1, 1, 1, 1);
+    mainLayout->setRowStretch(1, 10);
+    mainLayout->setColumnStretch(1, 10);
+    mainLayout->setMargin(KDialog::spacingHint());
+    mainLayout->setSpacing(KDialog::spacingHint());
+
+    // --------------------------------------------------------
+
+    QHBoxLayout *hBtnLayout = new QHBoxLayout;
+    hBtnLayout->addStretch(10);
+    hBtnLayout->addWidget(d->moveUpButton);
+    hBtnLayout->addWidget(d->addButton);
+    hBtnLayout->addWidget(d->removeButton);
+    hBtnLayout->addWidget(d->moveDownButton);
+    hBtnLayout->addWidget(d->loadButton);
+    hBtnLayout->addWidget(d->saveButton);
+    hBtnLayout->addWidget(d->clearButton);
+    hBtnLayout->addStretch(10);
+
+    // --------------------------------------------------------
+
+    QVBoxLayout *vBtnLayout = new QVBoxLayout;
+    vBtnLayout->addStretch(10);
+    vBtnLayout->addWidget(d->moveUpButton);
+    vBtnLayout->addWidget(d->addButton);
+    vBtnLayout->addWidget(d->removeButton);
+    vBtnLayout->addWidget(d->moveDownButton);
+    vBtnLayout->addWidget(d->loadButton);
+    vBtnLayout->addWidget(d->saveButton);
+    vBtnLayout->addWidget(d->clearButton);
+    vBtnLayout->addStretch(10);
+
+    // --------------------------------------------------------
+
+    switch (placement)
     {
-        connect(d->addButton, SIGNAL(clicked()),
-                this, SLOT(slotAddItems()));
-
-        connect(d->removeButton, SIGNAL(clicked()),
-                this, SLOT(slotRemoveItems()));
-
-        d->addButton->show();
-        d->removeButton->show();
-        d->plainPage->show();
+        case ControlButtonsAbove:
+            mainLayout->addLayout(hBtnLayout, 0, 1, 1, 1);
+            delete vBtnLayout;
+            break;
+        case ControlButtonsBelow:
+            mainLayout->addLayout(hBtnLayout, 2, 1, 1, 1);
+            delete vBtnLayout;
+            break;
+        case ControlButtonsLeft:
+            mainLayout->addLayout(vBtnLayout, 1, 0, 1, 1);
+            delete hBtnLayout;
+            break;
+        case ControlButtonsRight:
+            mainLayout->addLayout(vBtnLayout, 1, 2, 1, 1);
+            delete hBtnLayout;
+            break;
+        case NoControlButtons:
+        default:
+        {
+            delete vBtnLayout;
+            delete hBtnLayout;
+            // set all buttons invisible
+            setControlButtons(0x0);
+            break;
+        }
     }
+    setLayout(mainLayout);
+}
+
+void ImagesList::setControlButtons(ControlButtons buttonMask)
+{
+    d->addButton->setVisible(buttonMask & Add);
+    d->removeButton->setVisible(buttonMask & Remove);
+    d->moveUpButton->setVisible(buttonMask & MoveUp);
+    d->moveDownButton->setVisible(buttonMask & MoveDown);
+    d->clearButton->setVisible(buttonMask & Clear);
+    d->loadButton->setVisible(buttonMask & Load);
+    d->saveButton->setVisible(buttonMask & Save);
 }
 
 ImagesList::~ImagesList()
@@ -422,10 +541,10 @@ void ImagesList::loadImagesFromCurrentSelection()
 
 void ImagesList::slotAddImages(const KUrl::List& list)
 {
-    if (list.count() == 0) return;
+    if (list.count() == 0)
+        return;
 
     KUrl::List urls;
-
     bool raw = false;
 
     for ( KUrl::List::ConstIterator it = list.constBegin(); it != list.constEnd(); ++it )
@@ -433,7 +552,6 @@ void ImagesList::slotAddImages(const KUrl::List& list)
         KUrl imageUrl = *it;
 
         // Check if the new item already exist in the list.
-
         bool found = false;
 
         QTreeWidgetItemIterator iter(d->listView);
@@ -462,7 +580,7 @@ void ImagesList::slotAddImages(const KUrl::List& list)
 
     d->iface->thumbnails(urls, DEFAULTSIZE);
 
-    emit signalImageListChanged(imageUrls().isEmpty());
+    emit signalImageListChanged();
     emit signalFoundRAWImages(raw);
 }
 
@@ -492,7 +610,7 @@ void ImagesList::slotAddItems()
     if (!urls.isEmpty())
         slotAddImages(urls);
 
-    emit signalImageListChanged(imageUrls().isEmpty());
+    emit signalImageListChanged();
 }
 
 void ImagesList::slotRemoveItems()
@@ -504,7 +622,53 @@ void ImagesList::slotRemoveItems()
         ++it;
         delete item;
     }
-    emit signalImageListChanged(imageUrls().isEmpty());
+    emit signalImageListChanged();
+}
+
+void ImagesList::slotMoveUpItems()
+{
+    QModelIndex curIndex = listView()->currentIndex();
+    if (!curIndex.isValid())
+        return;
+
+    QModelIndex aboveIndex = listView()->indexAbove(curIndex);
+    if (!aboveIndex.isValid())
+        return;
+
+    QTreeWidgetItem* temp = listView()->takeTopLevelItem(aboveIndex.row());
+    listView()->insertTopLevelItem(curIndex.row(), temp);
+
+    emit signalImageListChanged();
+}
+
+void ImagesList::slotMoveDownItems()
+{
+    QModelIndex curIndex = listView()->currentIndex();
+    if (!curIndex.isValid())
+        return;
+
+    QModelIndex belowIndex = listView()->indexBelow(curIndex);
+    if (!belowIndex.isValid())
+        return;
+
+    QTreeWidgetItem* temp = listView()->takeTopLevelItem(belowIndex.row());
+    listView()->insertTopLevelItem(curIndex.row(), temp);
+
+    emit signalImageListChanged();
+}
+
+void ImagesList::slotClearItems()
+{
+    listView()->clear();
+    slotRemoveItems();
+}
+
+void ImagesList::slotLoadItems()
+{
+}
+
+void ImagesList::slotSaveItems()
+{
 }
 
 void ImagesList::removeItemByUrl(const KUrl& url)
@@ -528,7 +692,7 @@ void ImagesList::removeItemByUrl(const KUrl& url)
     }
     while (found);
 
-    emit signalImageListChanged(imageUrls().isEmpty());
+    emit signalImageListChanged();
 }
 
 KUrl::List ImagesList::imageUrls() const
@@ -544,11 +708,6 @@ KUrl::List ImagesList::imageUrls() const
     return list;
 }
 
-QWidget* ImagesList::plainPage() const
-{
-    return d->plainPage;
-}
-
 ImagesListView* ImagesList::listView() const
 {
     return d->listView;
@@ -570,4 +729,21 @@ bool ImagesList::isRAWFile(const QString & filePath)
     return false;
 }
 
+void ImagesList::slotImageListChanged()
+{
+    bool enable = !(imageUrls().isEmpty()) && d->controlButtonsEnabled;
+
+    d->addButton->setEnabled(enable);
+    d->removeButton->setEnabled(enable);
+    d->moveUpButton->setEnabled(enable);
+    d->moveDownButton->setEnabled(enable);
+    d->clearButton->setEnabled(enable);
+    d->loadButton->setEnabled(enable);
+    d->saveButton->setEnabled(enable);
+
+    // All buttons are enabled / disabled now, but the "Add" button should always be
+    // enabled, if the buttons are not explicitly disabled with enableControlButtons()
+    d->addButton->setEnabled(d->controlButtonsEnabled);
+}
+
 }  // namespace KIPIPlugins
