@@ -101,6 +101,9 @@ FlickrTalker::FlickrTalker(QWidget* parent, const QString& serviceName)
     m_apikey = "49d585bafa0758cb5c58ab67198bf632";
     m_secret = "34b39925e6273ffd";
 
+    /* Initialize selected photo set as empty. */
+    m_selectedPhotoSet = FPhotoSet();
+
     connect(this, SIGNAL(signalAuthenticate()),
             this, SLOT(slotAuthenticate()));
 }
@@ -165,7 +168,7 @@ void FlickrTalker::getFrob()
     url.addQueryItem("api_key", m_apikey);
     QString md5 = getApiSig(m_secret, url);
     url.addQueryItem("api_sig", md5);
-    kDebug( 51000 ) << "Get frob url: " << url << endl;
+    kDebug(51000) << "Get frob url: " << url << endl;
     QByteArray tmp;
     KIO::TransferJob* job = KIO::http_post(url, tmp, KIO::HideProgressInfo);
 
@@ -200,7 +203,7 @@ void FlickrTalker::checkToken(const QString& token)
     url.addQueryItem("auth_token", token);
     QString md5 = getApiSig(m_secret, url);
     url.addQueryItem("api_sig", md5);
-    kDebug( 51000 ) << "Check token url: " << url << endl;
+    kDebug(51000) << "Check token url: " << url << endl;
     QByteArray tmp;
     KIO::TransferJob* job = KIO::http_post(url, tmp, KIO::HideProgressInfo);
 
@@ -235,12 +238,12 @@ void FlickrTalker::slotAuthenticate()
     url.addQueryItem("perms", "write");
     QString md5 = getApiSig(m_secret, url);
     url.addQueryItem("api_sig", md5);
-    kDebug( 51000 ) << "Authenticate url: " << url << endl;
+    kDebug(51000) << "Authenticate url: " << url << endl;
 
     KToolInvocation::invokeBrowser(url.url());
     int valueOk = KMessageBox::questionYesNo(kapp->activeWindow(),
-                  i18n("Please Follow through the instructions in the browser window and "
-                       "return back to press ok if you are authenticated or press No"),
+                  i18n("Please follow the instructions in the browser window, then "
+                       "return to press Yes if you are authenticated, or No otherwise."),
                   i18n("%1 Service Web Authorization", m_serviceName));
 
     if( valueOk == KMessageBox::Yes)
@@ -253,7 +256,7 @@ void FlickrTalker::slotAuthenticate()
     }
     else
     {
-        kDebug( 51000 ) << "User didn't proceed with getToken Authorization, cannot proceed further, aborting" << endl;
+        kDebug(51000) << "User didn't proceed with getToken Authorization, cannot proceed further, aborting" << endl;
         cancel();
     }
 }
@@ -272,7 +275,7 @@ void FlickrTalker::getToken()
     url.addQueryItem("frob", m_frob);
     QString md5 = getApiSig(m_secret, url);
     url.addQueryItem("api_sig", md5);
-    kDebug( 51000 ) << "Get token url: " << url << endl;
+    kDebug(51000) << "Get token url: " << url << endl;
     QByteArray tmp;
     KIO::TransferJob* job = KIO::http_post(url, tmp, KIO::HideProgressInfo);
     job->addMetaData("content-type", "Content-Type: application/x-www-form-urlencoded");
@@ -339,7 +342,7 @@ void FlickrTalker::getPhotoProperty(const QString& method, const QStringList& ar
 
     QString md5 = getApiSig(m_secret, url);
     url.addQueryItem("api_sig", md5);
-    kDebug( 51000 ) << "Get photo property url: " << url << endl;
+    kDebug(51000) << "Get photo property url: " << url << endl;
     QByteArray tmp;
     KIO::TransferJob* job = KIO::http_post(url, tmp, KIO::HideProgressInfo);
     job->addMetaData("content-type", "Content-Type: application/x-www-form-urlencoded" );
@@ -373,7 +376,7 @@ void FlickrTalker::createPhotoSet(const QString& /*albumName*/, const QString& a
         m_job = 0;
     }
 
-    kDebug( 51000 ) << "create photoset invoked" << endl;
+    kDebug(51000) << "create photoset invoked" << endl;
     KUrl url(m_apiUrl);
     url.addQueryItem("auth_token", m_token);
     url.addQueryItem("api_key", m_apikey);
@@ -383,7 +386,7 @@ void FlickrTalker::createPhotoSet(const QString& /*albumName*/, const QString& a
     url.addQueryItem("primary_photo_id", primaryPhotoId);
     QString md5 = getApiSig(m_secret, url);
     url.addQueryItem("api_sig", md5);
-    kDebug( 51000 ) << "List photo sets url: " << url << endl;
+    kDebug(51000) << "List photo sets url: " << url << endl;
     QByteArray tmp;
     KIO::TransferJob* job = KIO::http_post(url, tmp, KIO::HideProgressInfo);
     job->addMetaData("content-type", "Content-Type: application/x-www-form-urlencoded" );
@@ -402,43 +405,51 @@ void FlickrTalker::createPhotoSet(const QString& /*albumName*/, const QString& a
 
 void FlickrTalker::addPhotoToPhotoSet(const QString& photoId,  const QString& photoSetId)
 {
-   if (m_job)
+    if (m_job)
     {
         m_job->kill();
         m_job = 0;
     }
 
-    kDebug( 51000 ) << "addPhotoToPhotoSet invoked" << endl;
+    kDebug(51000) << "addPhotoToPhotoSet invoked" << endl;
     KUrl url(m_apiUrl);
 
-    url.addQueryItem("auth_token", m_token);
+    /* If the photoset id starts with the special string "UNDEFINED_", it means
+     * it doesn't exist yet on Flickr and needs to be created. Note that it's
+     * not necessary to subsequently add the photo to the photo set, as this
+     * is done in the set creation call to Flickr. */
+    if (photoSetId.startsWith("UNDEFINED_")) {
+        createPhotoSet("", m_selectedPhotoSet.title, m_selectedPhotoSet.description, photoId);
+    } else {
+        url.addQueryItem("auth_token", m_token);
 
-    url.addQueryItem("photoset_id", photoSetId);
+        url.addQueryItem("photoset_id", photoSetId);
 
-    url.addQueryItem("api_key", m_apikey);
+        url.addQueryItem("api_key", m_apikey);
 
-    url.addQueryItem("method", "flickr.photosets.addPhoto");
+        url.addQueryItem("method", "flickr.photosets.addPhoto");
 
-    url.addQueryItem("photo_id", photoId);
+        url.addQueryItem("photo_id", photoId);
 
-    QString md5 = getApiSig(m_secret, url);
-    url.addQueryItem("api_sig", md5);
+        QString md5 = getApiSig(m_secret, url);
+        url.addQueryItem("api_sig", md5);
 
-    QByteArray tmp;
-    kDebug( 51000 ) << "Add photo to Photo set url: " << url << endl;
-    KIO::TransferJob* job = KIO::http_post(url, tmp, KIO::HideProgressInfo);
-    job->addMetaData("content-type", "Content-Type: application/x-www-form-urlencoded" );
+        QByteArray tmp;
+        kDebug(51000) << "Add photo to Photo set url: " << url << endl;
+        KIO::TransferJob* job = KIO::http_post(url, tmp, KIO::HideProgressInfo);
+        job->addMetaData("content-type", "Content-Type: application/x-www-form-urlencoded");
 
-    connect(job, SIGNAL(data(KIO::Job*, const QByteArray&)),
-            this, SLOT(data(KIO::Job*, const QByteArray&)));
+        connect(job, SIGNAL(data(KIO::Job*, const QByteArray&)),
+                this, SLOT(data(KIO::Job*, const QByteArray&)));
 
-    connect(job, SIGNAL(result(KJob *)),
-            this, SLOT(slotResult(KJob *)));
+        connect(job, SIGNAL(result(KJob *)),
+                this, SLOT(slotResult(KJob *)));
 
-    m_state = FE_ADDPHOTOTOPHOTOSET;
-    m_job   = job;
-    m_buffer.resize(0);
-    emit signalBusy(true);
+        m_state = FE_ADDPHOTOTOPHOTOSET;
+        m_job   = job;
+        m_buffer.resize(0);
+        emit signalBusy(true);
+    }
 }
 
 bool FlickrTalker::addPhoto(const QString& photoPath, const FPhotoInfo& info,
@@ -475,7 +486,7 @@ bool FlickrTalker::addPhoto(const QString& photoPath, const FPhotoInfo& info,
     form.addPair("is_friend", isfriend, "text/plain");
     url2.addQueryItem("is_friend", isfriend);
 
-    QString tags = info.tags.join(" ");
+    QString tags = "\"" + info.tags.join("\" \"") + "\"";
     if(tags.length() > 0)
     {
         form.addPair("tags", tags, "text/plain");
@@ -540,7 +551,7 @@ bool FlickrTalker::addPhoto(const QString& photoPath, const FPhotoInfo& info,
             kWarning(51000) << "(flickrExport::Image doesn't have metdata)" << endl;
         }
 
-        kDebug( 51000 ) << "Resizing and saving to temp file: " << path << endl;
+        kDebug(51000) << "Resizing and saving to temp file: " << path << endl;
     }
 
     if (!form.addFile("photo", path))
@@ -657,7 +668,7 @@ void FlickrTalker::slotError(const QString& error)
     };
 
     KMessageBox::error(kapp->activeWindow(),
-                 i18n("Error Occurred: %1\n We can not proceed further",transError));
+                 i18n("Error Occurred: %1\nCannot proceed any further.",transError));
 }
 
 void FlickrTalker::slotResult(KJob *kjob)
@@ -737,22 +748,22 @@ void FlickrTalker::parseResponseGetFrob(const QByteArray& data)
         if (node.isElement() && node.nodeName() == "frob")
         {
             QDomElement e = node.toElement();    // try to convert the node to an element.
-            kDebug( 51000 ) << "Frob is" << e.text() << endl;
+            kDebug(51000) << "Frob is" << e.text() << endl;
             m_frob        = e.text();            // this is what is obtained from data.
             success       = true;
         }
 
         if (node.isElement() && node.nodeName() == "err")
         {
-            kDebug( 51000 ) << "Checking Error in response" << endl;
+            kDebug(51000) << "Checking Error in response" << endl;
             errorString = node.toElement().attribute("code");
-            kDebug( 51000 ) << "Error code=" << errorString << endl;
-            kDebug( 51000 ) << "Msg=" << node.toElement().attribute("msg") << endl;
+            kDebug(51000) << "Error code=" << errorString << endl;
+            kDebug(51000) << "Msg=" << node.toElement().attribute("msg") << endl;
         }
         node = node.nextSibling();
     }
 
-    kDebug( 51000 ) << "GetFrob finished" << endl;
+    kDebug(51000) << "GetFrob finished" << endl;
     m_authProgressDlg->setMaximum(4);
     m_authProgressDlg->setValue(2);
     m_state = FE_GETAUTHORIZED;
@@ -794,13 +805,13 @@ void FlickrTalker::parseResponseCheckToken(const QByteArray& data)
 
                     if(details.nodeName() == "token")
                     {
-                        kDebug( 51000 ) << "Token=" << e.text() << endl;
+                        kDebug(51000) << "Token=" << e.text() << endl;
                         m_token = e.text();//this is what is obtained from data.
                     }
 
                     if(details.nodeName() == "perms")
                     {
-                        kDebug( 51000 ) << "Perms=" << e.text() << endl;
+                        kDebug(51000) << "Perms=" << e.text() << endl;
                         QString	perms = e.text();//this is what is obtained from data.
 
                         if(perms == "write")
@@ -813,12 +824,12 @@ void FlickrTalker::parseResponseCheckToken(const QByteArray& data)
 
                     if(details.nodeName() == "user")
                     {
-                        kDebug( 51000 ) << "nsid=" << e.attribute("nsid") << endl;
+                        kDebug(51000) << "nsid=" << e.attribute("nsid") << endl;
                         m_userId   = e.attribute("nsid");
                         username   = e.attribute("username");
                         m_username = username;
-                        kDebug( 51000 ) << "username=" << e.attribute("username") << endl;
-                        kDebug( 51000 ) << "fullname=" << e.attribute("fullname") << endl;
+                        kDebug(51000) << "username=" << e.attribute("username") << endl;
+                        kDebug(51000) << "fullname=" << e.attribute("fullname") << endl;
                     }
                 }
 
@@ -832,14 +843,14 @@ void FlickrTalker::parseResponseCheckToken(const QByteArray& data)
 
         if (node.isElement() && node.nodeName() == "err")
         {
-            kDebug( 51000 ) << "Checking Error in response" << endl;
+            kDebug(51000) << "Checking Error in response" << endl;
             errorString = node.toElement().attribute("code");
-            kDebug( 51000 ) << "Error code=" << errorString << endl;
-            kDebug( 51000 ) << "Msg=" << node.toElement().attribute("msg") << endl;
+            kDebug(51000) << "Error code=" << errorString << endl;
+            kDebug(51000) << "Msg=" << node.toElement().attribute("msg") << endl;
 
             int valueOk = KMessageBox::questionYesNo(kapp->activeWindow(),
                                        i18n("Your token is invalid. Would you like to "
-                                            "get a new token to proceed ?\n"));
+                                            "get a new token to proceed?\n"));
             if(valueOk == KMessageBox::Yes)
             {
                 getFrob();
@@ -858,7 +869,7 @@ void FlickrTalker::parseResponseCheckToken(const QByteArray& data)
     if(!success)
         emit signalError(errorString);
 
-    kDebug( 51000 ) << "CheckToken finished" << endl;
+    kDebug(51000) << "CheckToken finished" << endl;
 }
 
 void FlickrTalker::parseResponseGetToken(const QByteArray& data)
@@ -888,20 +899,20 @@ void FlickrTalker::parseResponseGetToken(const QByteArray& data)
 
                     if(details.nodeName() == "token")
                     {
-                        kDebug( 51000 ) << "Token=" << e.text() << endl;
+                        kDebug(51000) << "Token=" << e.text() << endl;
                         m_token = e.text();      //this is what is obtained from data.
                     }
 
                     if(details.nodeName() == "perms")
                     {
-                        kDebug( 51000 ) << "Perms=" << e.text() << endl;
+                        kDebug(51000) << "Perms=" << e.text() << endl;
                     }
 
                     if(details.nodeName() == "user")
                     {
-                        kDebug( 51000 ) << "nsid=" << e.attribute("nsid") << endl;
-                        kDebug( 51000 ) << "username=" << e.attribute("username") << endl;
-                        kDebug( 51000 ) << "fullname=" << e.attribute("fullname") << endl;
+                        kDebug(51000) << "nsid=" << e.attribute("nsid") << endl;
+                        kDebug(51000) << "username=" << e.attribute("username") << endl;
+                        kDebug(51000) << "fullname=" << e.attribute("fullname") << endl;
                         m_username = e.attribute("username");
                         m_userId   = e.attribute("nsid");
                     }
@@ -914,17 +925,17 @@ void FlickrTalker::parseResponseGetToken(const QByteArray& data)
         }
         else if (node.isElement() && node.nodeName() == "err")
         {
-            kDebug( 51000 ) << "Checking Error in response" << endl;
+            kDebug(51000) << "Checking Error in response" << endl;
             errorString = node.toElement().attribute("code");
-            kDebug( 51000 ) << "Error code=" << errorString << endl;
-            kDebug( 51000 ) << "Msg=" << node.toElement().attribute("msg") << endl;
+            kDebug(51000) << "Error code=" << errorString << endl;
+            kDebug(51000) << "Msg=" << node.toElement().attribute("msg") << endl;
             //emit signalError(code);
         }
 
         node = node.nextSibling();
     }
 
-    kDebug( 51000 ) << "GetToken finished" << endl;
+    kDebug(51000) << "GetToken finished" << endl;
     //emit signalBusy( false );
     m_authProgressDlg->hide();
 
@@ -936,7 +947,7 @@ void FlickrTalker::parseResponseGetToken(const QByteArray& data)
 
 void FlickrTalker::parseResponseCreatePhotoSet(const QByteArray& data)
 {
-    kDebug( 51000 ) << "Parse response create photoset recieved " << data << endl;
+    kDebug(51000) << "Parse response create photoset recieved " << data << endl;
 
     //bool success = false;
 
@@ -952,18 +963,32 @@ void FlickrTalker::parseResponseCreatePhotoSet(const QByteArray& data)
     {
         if (node.isElement() && node.nodeName() == "photoset")
         {
-            KMessageBox::information(kapp->activeWindow(),
-                                     i18n("PhotoSet created successfully"));
-            listPhotoSets();
+          // Parse the id from the response.
+          QString new_id = node.toElement().attribute("id");
+
+          // Set the new id in the photo sets list.
+          QLinkedList<FPhotoSet>::iterator it = m_photoSetsList->begin();
+          while(it != m_photoSetsList->end()) {
+            if (it->id == m_selectedPhotoSet.id) {
+              it->id = new_id;
+              break;
+            }
+            it++;
+          }
+          // Set the new id in the selected photo set.
+          m_selectedPhotoSet.id = new_id;
+
+          kDebug() << "PhotoSet created successfully with id" << new_id << endl;
+          emit signalAddPhotoSetSucceeded();
         }
 
         if (node.isElement() && node.nodeName() == "err")
         {
-            kDebug( 51000 ) << "Checking Error in response" << endl;
+            kDebug(51000) << "Checking Error in response" << endl;
             QString code = node.toElement().attribute("code");
-            kDebug( 51000 ) << "Error code=" << code << endl;
+            kDebug(51000) << "Error code=" << code << endl;
             QString msg = node.toElement().attribute("msg");
-            kDebug( 51000 ) << "Msg=" << msg << endl;
+            kDebug(51000) << "Msg=" << msg << endl;
             KMessageBox::error(kapp->activeWindow(), i18n("PhotoSet creation failed: ") + msg);
         }
 
@@ -973,7 +998,7 @@ void FlickrTalker::parseResponseCreatePhotoSet(const QByteArray& data)
 
 void FlickrTalker::parseResponseListPhotoSets(const QByteArray& data)
 {
-    kDebug( 51000 ) << "parseResponseListPhotosets" << data << endl;
+    kDebug(51000) << "parseResponseListPhotosets" << data << endl;
     bool success = false;
     QDomDocument doc("getListPhotoSets");
     if (!doc.setContent(data))
@@ -1001,7 +1026,7 @@ void FlickrTalker::parseResponseListPhotoSets(const QByteArray& data)
                     e = detailsNode.toElement();
                     if(detailsNode.nodeName() == "photoset")
                     {
-                        kDebug( 51000 ) << "id=" << e.attribute("id") << endl;
+                        kDebug(51000) << "id=" << e.attribute("id") << endl;
                         photoSet_id              = e.attribute("id");     // this is what is obtained from data.
                         fps.id                   = photoSet_id;
                         QDomNode photoSetDetails = detailsNode.firstChild();
@@ -1013,13 +1038,13 @@ void FlickrTalker::parseResponseListPhotoSets(const QByteArray& data)
 
                             if(photoSetDetails.nodeName() == "title")
                             {
-                                kDebug( 51000 ) << "Title=" << e_detail.text() << endl;
+                                kDebug(51000) << "Title=" << e_detail.text() << endl;
                                 photoSet_title = e_detail.text();
                                 fps.title      = photoSet_title;
                             }
                             else if(photoSetDetails.nodeName() == "description")
                             {
-                                kDebug( 51000 ) << "Description =" << e_detail.text() << endl;
+                                kDebug(51000) << "Description =" << e_detail.text() << endl;
                                 photoSet_description = e_detail.text();
                                 fps.description      = photoSet_description;
                             }
@@ -1040,21 +1065,21 @@ void FlickrTalker::parseResponseListPhotoSets(const QByteArray& data)
 
         if (node.isElement() && node.nodeName() == "err")
         {
-            kDebug( 51000 ) << "Checking Error in response" << endl;
+            kDebug(51000) << "Checking Error in response" << endl;
             QString code = node.toElement().attribute("code");
-            kDebug( 51000 ) << "Error code=" << code << endl;
-            kDebug( 51000 ) << "Msg=" << node.toElement().attribute("msg") << endl;
+            kDebug(51000) << "Error code=" << code << endl;
+            kDebug(51000) << "Msg=" << node.toElement().attribute("msg") << endl;
             emit signalError(code);
         }
 
         node = node.nextSibling();
     }
 
-    kDebug( 51000 ) << "GetPhotoList finished" << endl;
+    kDebug(51000) << "GetPhotoList finished" << endl;
 
     if (!success)
     {
-        emit signalListPhotoSetsFailed(i18n("Failed to fetch photoSets List"));
+        emit signalListPhotoSetsFailed(i18n("Failed to fetch list of photo sets."));
     }
     else
     {
@@ -1106,16 +1131,16 @@ void FlickrTalker::parseResponseAddPhoto(const QByteArray& data)
             e                = node.toElement();           // try to convert the node to an element.
             QDomNode details = e.firstChild();
             photoId = e.text();
-            kDebug( 51000 ) << "Photoid= " << photoId << endl;
+            kDebug(51000) << "Photoid= " << photoId << endl;
             success = true;
         }
 
         if (node.isElement() && node.nodeName() == "err")
         {
-            kDebug( 51000 ) << "Checking Error in response" << endl;
+            kDebug(51000) << "Checking Error in response" << endl;
             QString code = node.toElement().attribute("code");
-            kDebug( 51000 ) << "Error code=" << code << endl;
-            kDebug( 51000 ) << "Msg=" << node.toElement().attribute("msg") << endl;
+            kDebug(51000) << "Error code=" << code << endl;
+            kDebug(51000) << "Msg=" << node.toElement().attribute("msg") << endl;
             emit signalError(code);
         }
 
@@ -1128,10 +1153,10 @@ void FlickrTalker::parseResponseAddPhoto(const QByteArray& data)
     }
     else
     {
-        QString photoSetId = m_selectedPhotoSetId;
-        if (photoSetId == "")
+        QString photoSetId = m_selectedPhotoSet.id;
+        if (photoSetId == "-1")
         {
-            kDebug( 51000 ) << "PhotoSet Id not set, not adding the photo to any photoset";
+            kDebug(51000) << "PhotoSet Id not set, not adding the photo to any photoset";
             emit signalAddPhotoSucceeded();
         }
         else
@@ -1159,23 +1184,23 @@ void FlickrTalker::parseResponsePhotoProperty(const QByteArray& data)
         {
             e = node.toElement();                 // try to convert the node to an element.
             QDomNode details = e.firstChild();
-            kDebug( 51000 ) << "Photoid=" << e.text() << endl;
+            kDebug(51000) << "Photoid=" << e.text() << endl;
             success = true;
         }
 
         if (node.isElement() && node.nodeName() == "err")
         {
-            kDebug( 51000 ) << "Checking Error in response" << endl;
+            kDebug(51000) << "Checking Error in response" << endl;
             QString code = node.toElement().attribute("code");
-            kDebug( 51000 ) << "Error code=" << code << endl;
-            kDebug( 51000 ) << "Msg=" << node.toElement().attribute("msg") << endl;
+            kDebug(51000) << "Error code=" << code << endl;
+            kDebug(51000) << "Msg=" << node.toElement().attribute("msg") << endl;
             emit signalError(code);
         }
 
         node = node.nextSibling();
     }
 
-    kDebug( 51000 ) << "GetToken finished" << endl;
+    kDebug(51000) << "GetToken finished" << endl;
 
     if (!success)
     {
@@ -1189,7 +1214,7 @@ void FlickrTalker::parseResponsePhotoProperty(const QByteArray& data)
 
 void FlickrTalker::parseResponseAddPhotoToPhotoSet(const QByteArray& data)
 {
-    kDebug( 51000 ) << "parseResponseListPhotosets" << data << endl;
+    kDebug(51000) << "parseResponseListPhotosets" << data << endl;
     emit signalAddPhotoSucceeded();
 }
 
