@@ -71,7 +71,6 @@ namespace KIPIFlickrExportPlugin
 class FlickrWidget;
 class FlickrTalker;
 class FPhotoInfo;
-class FPhotoSet;
 class GPhoto;
 class GAlbum;
 //class GAlbumViewItem;
@@ -83,7 +82,7 @@ class FlickrWindow : public KDialog
 
 public:
 
-    FlickrWindow(KIPI::Interface *interface, const QString &tmpFolder, 
+    FlickrWindow(KIPI::Interface *interface, const QString &tmpFolder,
                  QWidget *parent, const QString& serviceName);
     ~FlickrWindow();
 
@@ -113,7 +112,7 @@ private slots:
     void slotHelp();
     void slotClose();
     void slotUser1();
-    void slotImageListChanged(bool);
+    void slotImageListChanged();
 
 private:
 
