@@ -244,7 +244,7 @@ bool GalleryTalker::addPhoto(const QString& albumName,
         }
         path = KStandardDirs::locateLocal("tmp", KUrl(photoPath).fileName());
         image.save(path);
-        kDebug(51000) << "Resizing and saving to temp file: " << path << endl;
+        kDebug(51000) << "Resizing and saving to temp file: " << path ;
 
         // Restore all metadata.
         KExiv2Iface::KExiv2 exiv2Iface;
@@ -633,11 +633,11 @@ void GalleryTalker::parseResponseCreateAlbum(const QByteArray& data)
                 if (key == "status")      // key == "status" NOT FOUND!!!
                 {
                     success = (value == "0");
-                    kWarning( 51000 ) << "Create Album. success: " << success << endl;
+                    kWarning( 51000 ) << "Create Album. success: " << success ;
                 }
                 else if (key.startsWith("status_text"))
                 {
-                    kDebug(51000) << "STATUS: Create Album: " << value << endl;
+                    kDebug(51000) << "STATUS: Create Album: " << value ;
                 }
             }
         }
@@ -689,11 +689,11 @@ void GalleryTalker::parseResponseAddPhoto(const QByteArray& data)
                 if (key == "status")
                 {
                     success = (value == "0");
-                    kWarning( 51000 ) << "Add photo. success: " << success << endl;
+                    kWarning( 51000 ) << "Add photo. success: " << success ;
                 }
                 else if (key.startsWith("status_text"))
                 {
-                    kDebug(51000) << "STATUS: Add Photo: " << value << endl;
+                    kDebug(51000) << "STATUS: Add Photo: " << value ;
                 }
             }
         }
