@@ -49,7 +49,7 @@ public:
 
     GPSDataContainer getGPSInfo();
 
-protected slots:
+protected Q_SLOTS:
 
     void slotOk();
     void slotCancel();
@@ -61,8 +61,8 @@ protected slots:
 
 protected:
 
-    void resizeEvent(QResizeEvent *);
-    void closeEvent(QCloseEvent *);
+    void resizeEvent(QResizeEvent*);
+    void closeEvent(QCloseEvent*);
 
 private:
 
