@@ -61,6 +61,7 @@
 #include "imageslist.h"
 #include "kpaboutdata.h"
 #include "pluginsversion.h"
+#include "gpslistviewcontextmenu.h"
 
 namespace KIPIGPSSyncPlugin
 {
@@ -71,7 +72,7 @@ public:
 
     GPSSyncDialogPriv()
     {
-        imagesList       = 0;
+        imagesList     = 0;
         interface      = 0;
         maxGapInput    = 0;
         gpxFileName    = 0;
@@ -131,8 +132,8 @@ GPSSyncDialog::GPSSyncDialog(KIPI::Interface* interface, QWidget* parent)
 
     // --------------------------------------------------------------
 
-    d->imagesList = new KIPIPlugins::ImagesList(d->interface, this,
-                                     KIPIPlugins::ImagesList::NoControlButtons);
+    d->imagesList = new KIPIPlugins::ImagesList(d->interface, this);
+    d->imagesList->setControlButtonsPlacement(KIPIPlugins::ImagesList::NoControlButtons);
     d->imagesList->setAllowRAW(true);
     d->imagesList->listView()->setColumn(KIPIPlugins::ImagesListView::User1,
                                        i18n("Date"), true);
@@ -145,6 +146,10 @@ GPSSyncDialog::GPSSyncDialog(KIPI::Interface* interface, QWidget* parent)
     d->imagesList->listView()->setColumn(KIPIPlugins::ImagesListView::User5,
                                        i18n("Status"), true);
     d->imagesList->setMinimumWidth(450);
+
+    // add the context menu provider to the imagesList:
+    new GPSListViewContextMenu(d->imagesList);
+
 //    d->listView->setIconSize(QSize(64, 64));
 //    d->listView->setColumnWidth(0, 70);
 
@@ -257,8 +262,8 @@ GPSSyncDialog::GPSSyncDialog(KIPI::Interface* interface, QWidget* parent)
     d->about = new KIPIPlugins::KPAboutData(ki18n("GPS Sync"),
                    0,
                    KAboutData::License_GPL,
-                   ki18n("A Plugin to synchronize pictures metadata with a GPS device"),
-                   ki18n("(c) 2006-2008, Gilles Caulier"));
+                   ki18n("A Plugin to synchronize pictures' metadata with a GPS device"),
+                   ki18n("(c) 2006-2009, Gilles Caulier"));
 
     d->about->addAuthor(ki18n("Gilles Caulier"),
                         ki18n("Developer and maintainer"),
@@ -336,7 +341,7 @@ void GPSSyncDialog::slotLoadGPXFile()
 
     if (!ret)
     {
-        KMessageBox::error(this, i18n("Cannot parse %1 GPX file!",
+        KMessageBox::error(this, i18n("Cannot parse %1 GPX file.",
                            loadGPXFile.fileName()), i18n("GPS Sync"));
         enableButton(User1, false);
         return;
@@ -344,7 +349,7 @@ void GPSSyncDialog::slotLoadGPXFile()
 
     if (d->gpxParser.numPoints() <= 0)
     {
-        KMessageBox::sorry(this, i18n("The %1 GPX file do not have a date-time track to use!",
+        KMessageBox::sorry(this, i18n("The %1 GPX file does not have a date-time track to use.",
                            loadGPXFile.fileName()), i18n("GPS Sync"));
         enableButton(User1, false);
         return;
@@ -485,11 +490,11 @@ void GPSSyncDialog::slotUser1()
         return;
     }
 
-    QString msg = i18np("GPS data of 1 image have been updated on the list using the GPX data file.",
-                        "GPS data of %1 images have been updated on the list using the GPX data file.",
+    QString msg = i18np("The GPS data of 1 image have been updated using the GPX data file.",    // this is correct - data is plural
+                        "The GPS data of %1 images have been updated using the GPX data file.",
                         itemsUpdated);
     msg += '\n';
-    msg += i18n("Press Apply button to update images metadata.");
+    msg += i18np("Press the Apply button to update the image's metadata.","Press the Apply button to update the images' metadata.", itemsUpdated);
 
     KMessageBox::information(this, msg, i18n("GPS Sync"));
 }
@@ -499,7 +504,7 @@ void GPSSyncDialog::slotUser2()
 {
     if (!d->imagesList->listView()->currentItem())
     {
-        KMessageBox::information(this, i18n("Please, select at least one image from "
+        KMessageBox::information(this, i18n("Please select at least one image from "
                      "the list to edit GPS coordinates manually."), i18n("GPS Sync"));
         return;
     }
@@ -534,8 +539,8 @@ void GPSSyncDialog::slotUser3()
 {
     if (!d->imagesList->listView()->currentItem())
     {
-        KMessageBox::information(this, i18n("Please, select at least one image from "
-                     "the list to remove GPS coordinates."), i18n("GPS Sync"));
+        KMessageBox::information(this, i18n("Please select at least one image from "
+                     "which to remove GPS coordinates."), i18n("GPS Sync"));
         return;
     }
 
