@@ -91,8 +91,8 @@ GPSTrackListEditDialog::GPSTrackListEditDialog(KIPI::Interface* interface, QWidg
     setMainWidget( page );
 
     QVBoxLayout* vlay = new QVBoxLayout(page);
-    d->imagesList     = new KIPIPlugins::ImagesList(d->interface, this,
-                                     KIPIPlugins::ImagesList::NoControlButtons);
+    d->imagesList     = new KIPIPlugins::ImagesList(d->interface, this);
+    d->imagesList->setControlButtonsPlacement(KIPIPlugins::ImagesList::NoControlButtons);
     d->imagesList->setAllowRAW(true);
     d->imagesList->listView()->setColumn(KIPIPlugins::ImagesListView::User1,
                                        i18n("Id"), true);
