@@ -41,10 +41,6 @@
 #include <klocale.h>
 #include <ktextedit.h>
 
-// LibKExiv2 includes
-
-#include <libkexiv2/kexiv2.h>
-
 // LibKDcraw includes
 
 #include <libkdcraw/squeezedcombobox.h>
@@ -69,7 +65,6 @@ public:
         repValueButton = 0;
         valueBox       = 0;
         valueCheck     = 0;
-        valueBox       = 0;
         languageCB     = 0;
 
         // We cannot use KLocale::allLanguagesList() here because KDE only
@@ -100,7 +95,7 @@ public:
         languageCodeMap.insert( "ar-TN", i18n("Arabic (Tunisia)") );
         languageCodeMap.insert( "ar-YE", i18n("Arabic (Yemen)") );
         languageCodeMap.insert( "as-IN", i18n("Assamese (India)") );
-        languageCodeMap.insert( "ba-RU", i18n("Bashkir(Russia)") );
+        languageCodeMap.insert( "ba-RU", i18n("Bashkir (Russia)") );
         languageCodeMap.insert( "be-BY", i18n("Belarusian (Belarus)") );
         languageCodeMap.insert( "bg-BG", i18n("Bulgarian (Bulgaria)") );
         languageCodeMap.insert( "bn-IN", i18n("Bengali (India)") );
@@ -286,7 +281,7 @@ AltLangStringsEdit::AltLangStringsEdit(QWidget* parent, const QString& title, co
     d->delValueButton = new QPushButton(this);
     d->repValueButton = new QPushButton(this);
     d->addValueButton->setIcon(SmallIcon("list-add"));
-    d->delValueButton->setIcon(SmallIcon("edit-delete"));
+    d->delValueButton->setIcon(SmallIcon("list-remove"));
     d->repValueButton->setIcon(SmallIcon("view-refresh"));
     d->addValueButton->setWhatsThis(i18n("Add a new value to the list"));
     d->delValueButton->setWhatsThis(i18n("Remove the current selected value from the list"));
@@ -310,14 +305,14 @@ AltLangStringsEdit::AltLangStringsEdit(QWidget* parent, const QString& title, co
     // --------------------------------------------------------
 
     grid->setAlignment( Qt::AlignTop );
-    grid->addWidget(d->valueCheck,                  0, 0, 1, 1 );
-    grid->addWidget(d->addValueButton,              0, 2, 1, 1);
-    grid->addWidget(d->delValueButton,              0, 3, 1, 1);
-    grid->addWidget(d->repValueButton,              0, 4, 1, 1);
-    grid->addWidget(d->valueBox,                    0, 5, 3, 1);
-    grid->addWidget(new QLabel(i18n("Language:")),  1, 0, 1, 1);
-    grid->addWidget(d->languageCB,                  1, 1, 1, 4);
-    grid->addWidget(d->valueEdit,                   2, 0, 1, 5);
+    grid->addWidget(d->valueCheck,                 0, 0, 1, 1);
+    grid->addWidget(d->addValueButton,             0, 2, 1, 1);
+    grid->addWidget(d->delValueButton,             0, 3, 1, 1);
+    grid->addWidget(d->repValueButton,             0, 4, 1, 1);
+    grid->addWidget(d->valueBox,                   0, 5, 3, 1);
+    grid->addWidget(new QLabel(i18n("Language:")), 1, 0, 1, 1);
+    grid->addWidget(d->languageCB,                 1, 1, 1, 4);
+    grid->addWidget(d->valueEdit,                  2, 0, 1, 5);
     grid->setColumnStretch(1, 5);
     grid->setColumnStretch(5, 10);
     grid->setMargin(0);
