@@ -140,6 +140,10 @@ PrintOptionsPage::PrintOptionsPage (QWidget *parent, QList<TPhoto*> *photoList )
     d->mScaleGroup.addButton ( d->mScaleTo, ScaleToCustomSize );
     d->mPhotoXPage->setRange (0, d->m_photos->size() );
 
+    d->mPX->setSpecialValueText(i18n("disabled"));
+    d->mPY->setSpecialValueText(i18n("disabled"));
+    d->mPhotoXPage->setSpecialValueText(i18n("disabled"));
+
     imagePreview();
     enableButtons();
 
@@ -153,6 +157,8 @@ PrintOptionsPage::PrintOptionsPage (QWidget *parent, QList<TPhoto*> *photoList )
               SLOT ( adjustHeightToRatio() ) );
 
     connect (d->mPhotoXPage, SIGNAL(valueChanged (int)), SLOT(photoXpageChanged(int)));
+    connect (d->mPX, SIGNAL(valueChanged (int)), SLOT(horizontalPagesChanged(int)));
+    connect (d->mPY, SIGNAL(valueChanged (int)), SLOT(verticalPagesChanged(int)));
 
     connect ( d->mRightButton, SIGNAL ( clicked() ),
               this, SLOT ( selectNext() ) );
@@ -194,7 +200,7 @@ double PrintOptionsPage::unitToInches ( PrintOptionsPage::Unit unit )
 Qt::Alignment PrintOptionsPage::alignment() const
 {
     int id = d->mPositionGroup.checkedId();
-    kWarning(51000) << "alignment=" << id;
+    kDebug(51000) << "alignment=" << id;
     return Qt::Alignment ( id );
 }
 
@@ -248,7 +254,7 @@ void PrintOptionsPage::adjustHeightToRatio()
 
 void PrintOptionsPage::manageQPrintDialogChanges ( QPrinter * /*printer*/ )
 {
-    kWarning(51000) << "It has been called!" << endl;
+    kDebug(51000) << "It has been called!" << endl;
 }
 
 int PrintOptionsPage::photoXPage() const
@@ -256,6 +262,15 @@ int PrintOptionsPage::photoXPage() const
     return d->mPhotoXPage->value();
 }
 
+int PrintOptionsPage::mp_horPages() const
+{
+    return d->mPX->value();
+}
+
+int PrintOptionsPage::mp_verPages() const
+{
+    return d->mPY->value();
+}
 bool PrintOptionsPage::printUsingAtkinsLayout() const
 {
     return (d->mPhotoXPage->value() > 0);
@@ -287,7 +302,7 @@ void PrintOptionsPage::enableButtons()
 
 void PrintOptionsPage::imagePreview()
 {
-    kWarning(51000) << d->m_currentPhoto << endl;
+    kDebug(51000) << d->m_currentPhoto << endl;
     TPhoto *pPhoto = d->m_photos->at(d->m_currentPhoto);
     d->mPreview->setPixmap ( pPhoto->thumbnail() );
     if (pPhoto->cropRegion != QRect())
@@ -298,7 +313,7 @@ void PrintOptionsPage::imagePreview()
 
 void PrintOptionsPage::selectNext()
 {
-    kWarning(51000) << d->m_currentPhoto << endl;
+    kDebug(51000) << d->m_currentPhoto << endl;
 
     d->m_photos->at(d->m_currentPhoto)->pAddInfo->mPrintPosition = alignment();
     if (d->m_currentPhoto+1 < d->m_photos->size())
@@ -311,7 +326,7 @@ void PrintOptionsPage::selectNext()
 
 void PrintOptionsPage::selectPrev()
 {
-    kWarning(51000) << d->m_currentPhoto << endl;
+    kDebug(51000) << d->m_currentPhoto << endl;
     d->m_photos->at(d->m_currentPhoto)->pAddInfo->mPrintPosition = alignment();
     if (d->m_currentPhoto-1 >= 0)
         d->m_currentPhoto--;
@@ -444,11 +459,71 @@ void PrintOptionsPage::photoXpageChanged ( int i )
   {
     d->mRightButton->setDisabled(disabled);
     d->mLeftButton->setDisabled(disabled);
+    SignalBlocker block_mPX ( d->mPX );
+    d->mPX->setValue(0);
+    SignalBlocker block_mPY ( d->mPY );
+    d->mPY->setValue(0);
   }
   else
     enableButtons();
 }
 
+void PrintOptionsPage::horizontalPagesChanged ( int i )
+{
+  bool disabled = (i>0);
+  d->mPositionFrame->setDisabled(disabled);
+  d->mGroupScaling->setDisabled(disabled);
+  d->mGroupImage->setDisabled(disabled);
+  d->kcfg_PrintAutoRotate->setDisabled(disabled);
+  d->mPreview->setDisabled(disabled);
+  if (disabled)
+  {
+    d->mRightButton->setDisabled(disabled);
+    d->mLeftButton->setDisabled(disabled);
+    SignalBlocker blocker ( d->mPhotoXPage );
+    d->mPhotoXPage->setValue(0);
+    if (d->mPY->value() == 0)
+    {
+      SignalBlocker block_mPY ( d->mPY );
+      d->mPY->setValue(1);
+    }
+  }
+  else
+  {
+    SignalBlocker block_mPX ( d->mPY );
+    d->mPY->setValue(0);
+    enableButtons();
+  }
+}
+
+void PrintOptionsPage::verticalPagesChanged ( int i )
+{
+  bool disabled = (i>0);
+  d->mPositionFrame->setDisabled(disabled);
+  d->mGroupScaling->setDisabled(disabled);
+  d->mGroupImage->setDisabled(disabled);
+  d->kcfg_PrintAutoRotate->setDisabled(disabled);
+  d->mPreview->setDisabled(disabled);
+  if (disabled)
+  {
+    d->mRightButton->setDisabled(disabled);
+    d->mLeftButton->setDisabled(disabled);
+    SignalBlocker blocker ( d->mPhotoXPage );
+    d->mPhotoXPage->setValue(0);
+    if (d->mPX->value() == 0)
+    {
+      SignalBlocker block_mPX ( d->mPX );
+      d->mPX->setValue(1);
+    }
+  }
+  else
+  {
+    SignalBlocker block_mPX ( d->mPX );
+    d->mPX->setValue(0);
+    enableButtons();
+  }
+}
+
 void PrintOptionsPage::scaleOption()
 {
   ScaleMode scaleMode = ScaleMode ( d->mScaleGroup.checkedId() );
