@@ -24,7 +24,7 @@
 #include "singledialog.h"
 #include "singledialog.moc"
 
-// C ANSI includes.
+// C ANSI includes
 
 extern "C"
 {
@@ -33,11 +33,11 @@ extern "C"
 #include <unistd.h>
 }
 
-// C++ includes.
+// C++ includes
 
 #include <cstdio>
 
-// Qt includes.
+// Qt includes
 
 #include <QCloseEvent>
 #include <QFile>
@@ -46,7 +46,7 @@ extern "C"
 #include <QPushButton>
 #include <QTimer>
 
-// KDE includes.
+// KDE includes
 
 #include <kapplication.h>
 #include <kconfig.h>
@@ -62,17 +62,17 @@ extern "C"
 #include <kstandarddirs.h>
 #include <ktoolinvocation.h>
 
-// LibKDcraw includes.
+// LibKDcraw includes
 
 #include <libkdcraw/version.h>
 #include <libkdcraw/dcrawsettingswidget.h>
 
-// LibKIPI includes.
+// LibKIPI includes
 
 #include <libkipi/interface.h>
 #include <libkipi/imageinfo.h>
 
-// Local includes.
+// Local includes
 
 #include "actions.h"
 #include "actionthread.h"
@@ -140,7 +140,7 @@ SingleDialog::SingleDialog(const QString& file, KIPI::Interface* iface)
     setButtonText(User1, i18n("&Preview"));
     setButtonText(User2, i18n("Con&vert"));
     setButtonText(User3, i18n("&Abort"));
-    setCaption(i18n("Raw Image Converter"));
+    setCaption(i18n("RAW Image Converter"));
     setModal(false);
 
     QWidget *page = new QWidget( this );
@@ -157,15 +157,21 @@ SingleDialog::SingleDialog(const QString& file, KIPI::Interface* iface)
                                                            DcrawSettingsWidget::BLACKWHITEPOINTS);
     d->saveSettingsBox     = new SaveSettingsWidget(d->decodingSettingsBox);
 
+#if KDCRAW_VERSION <= 0x000500
     d->decodingSettingsBox->addItem(d->saveSettingsBox, i18n("Save settings"));
     d->decodingSettingsBox->updateMinimumWidth();
+#else
+    d->decodingSettingsBox->addItem(d->saveSettingsBox, i18n("Save settings"), QString("savesettings"), false);
+#endif
 
-    mainLayout->addWidget(d->previewWidget,         0, 0, 2, 1);
-    mainLayout->addWidget(d->decodingSettingsBox,   0, 1, 1, 1);
-    mainLayout->setColumnStretch(0, 10);
-    mainLayout->setRowStretch(1, 10);
+    mainLayout->addWidget(d->previewWidget,       0, 0, 2, 1);
+    mainLayout->addWidget(d->decodingSettingsBox, 0, 1, 1, 1);
     mainLayout->setMargin(0);
     mainLayout->setSpacing(spacingHint());
+    mainLayout->setColumnStretch(0, 10);
+#if KDCRAW_VERSION <= 0x000500
+    mainLayout->setRowStretch(1, 10);
+#endif
 
     // ---------------------------------------------------------------
     // About data and help button.
@@ -173,7 +179,7 @@ SingleDialog::SingleDialog(const QString& file, KIPI::Interface* iface)
     d->about = new KIPIPlugins::KPAboutData(ki18n("RAW Image Converter"),
                    0,
                    KAboutData::License_GPL,
-                   ki18n("A Kipi plugin to convert a Raw image"),
+                   ki18n("A Kipi plugin to convert RAW images"),
                    ki18n("(c) 2003-2005, Renchi Raju\n"
                          "(c) 2006-2009, Gilles Caulier"));
 
@@ -198,16 +204,16 @@ SingleDialog::SingleDialog(const QString& file, KIPI::Interface* iface)
 
     // ---------------------------------------------------------------
 
-    setButtonToolTip(User1, i18n("Generate a Preview from current settings. "
+    setButtonToolTip(User1, i18n("Generate a preview using current settings. "
                                  "Uses a simple bilinear interpolation for "
                                  "quick results."));
 
-    setButtonToolTip(User2, i18n("Convert the Raw Image from current settings. "
+    setButtonToolTip(User2, i18n("Convert the RAW Image using current settings. "
                                  "This uses a high-quality adaptive algorithm."));
 
-    setButtonToolTip(User3, i18n("Abort the current Raw file conversion"));
+    setButtonToolTip(User3, i18n("Abort the current RAW file conversion"));
 
-    setButtonToolTip(Close, i18n("Exit Raw Converter"));
+    setButtonToolTip(Close, i18n("Exit RAW Converter"));
 
     d->blinkPreviewTimer = new QTimer(this);
     d->blinkConvertTimer = new QTimer(this);
@@ -324,6 +330,9 @@ void SingleDialog::readSettings()
     d->decodingSettingsBox->setUseCACorrection(group.readEntry("EnableCACorrection", false));
     d->decodingSettingsBox->setcaRedMultiplier(group.readEntry("caRedMultiplier", 1.0));
     d->decodingSettingsBox->setcaBlueMultiplier(group.readEntry("caBlueMultiplier", 1.0));
+#if KDCRAW_VERSION >= 0x000500
+    d->decodingSettingsBox->setAutoBrightness(group.readEntry("AutoBrightness", true));
+#endif
 
     d->decodingSettingsBox->setQuality(
         (KDcrawIface::RawDecodingSettings::DecodingQuality)group.readEntry("Decoding Quality",
@@ -372,7 +381,9 @@ void SingleDialog::saveSettings()
     group.writeEntry("caBlueMultiplier", d->decodingSettingsBox->caBlueMultiplier());
     group.writeEntry("Decoding Quality", (int)d->decodingSettingsBox->quality());
     group.writeEntry("Output Color Space", (int)d->decodingSettingsBox->outputColorSpace());
-
+#if KDCRAW_VERSION >= 0x000500
+    group.writeEntry("AutoBrightness", d->decodingSettingsBox->useAutoBrightness());
+#endif
     group.writeEntry("Output Format", (int)d->saveSettingsBox->fileFormat());
     group.writeEntry("Conflict", (int)d->saveSettingsBox->conflictRule());
 
@@ -405,6 +416,9 @@ void SingleDialog::slotUser1()
     rawDecodingSettings.caMultiplier[1]            = d->decodingSettingsBox->caBlueMultiplier();
     rawDecodingSettings.RAWQuality                 = d->decodingSettingsBox->quality();
     rawDecodingSettings.outputColorSpace           = d->decodingSettingsBox->outputColorSpace();
+#if KDCRAW_VERSION >= 0x000500
+        rawDecodingSettings.autoBrightness         = d->decodingSettingsBox->useAutoBrightness();
+#endif
 
     d->thread->setRawDecodingSettings(rawDecodingSettings, SaveSettingsWidget::OUTPUT_PNG);
     d->thread->processHalfRawFile(KUrl(d->inputFile));
@@ -436,6 +450,9 @@ void SingleDialog::slotUser2()
     rawDecodingSettings.caMultiplier[1]            = d->decodingSettingsBox->caBlueMultiplier();
     rawDecodingSettings.RAWQuality                 = d->decodingSettingsBox->quality();
     rawDecodingSettings.outputColorSpace           = d->decodingSettingsBox->outputColorSpace();
+#if KDCRAW_VERSION >= 0x000500
+        rawDecodingSettings.autoBrightness         = d->decodingSettingsBox->useAutoBrightness();
+#endif
 
     d->thread->setRawDecodingSettings(rawDecodingSettings, d->saveSettingsBox->fileFormat());
     d->thread->processRawFile(KUrl(d->inputFile));
@@ -556,7 +573,7 @@ void SingleDialog::processed(const KUrl& url, const QString& tmpFile)
         struct stat statBuf;
         if (::stat(QFile::encodeName(destFile), &statBuf) == 0)
         {
-            KIO::RenameDialog dlg(this, i18n("Save Raw Image converted from '%1' as", fi.fileName()),
+            KIO::RenameDialog dlg(this, i18n("Save RAW image converted from '%1' as", fi.fileName()),
                                   tmpFile, destFile,
                                   KIO::RenameDialog_Mode(KIO::M_SINGLE | KIO::M_OVERWRITE | KIO::M_SKIP));
 
@@ -600,7 +617,7 @@ void SingleDialog::processingFailed(const KUrl& /*url*/)
 {
     d->previewWidget->unsetCursor();
     d->blinkConvertTimer->stop();
-    d->previewWidget->setIdentity(i18n("Failed to convert Raw image"), Qt::red);
+    d->previewWidget->setIdentity(i18n("Failed to convert RAW image"), Qt::red);
 }
 
 void SingleDialog::slotPreviewBlinkTimerDone()
@@ -618,7 +635,7 @@ void SingleDialog::slotPreviewBlinkTimerDone()
 
 void SingleDialog::slotConvertBlinkTimerDone()
 {
-    QString convert = i18n("Converting Raw Image...");
+    QString convert = i18n("Converting RAW Image...");
 
     if (d->convertBlink)
         d->previewWidget->setIdentity(convert, Qt::green);
