@@ -58,6 +58,7 @@
 #include "commonsettings.h"
 #include "haarsettingswidget.h"
 #include "kpaboutdata.h"
+#include "imageslist.h"
 #include "myimageslist.h"
 #include "previewwidget.h"
 #include "simplesettings.h"
@@ -66,6 +67,8 @@
 #include "workerthread.h"
 #include "workerthreaddata.h"
 
+using namespace KIPIPlugins;
+
 namespace KIPIRemoveRedEyesPlugin
 {
 
@@ -88,8 +91,19 @@ public:
         saveMethod              = 0;
         unprocessedSettingsBox  = 0;
         storageSettingsBox      = 0;
+        totalLabel              = 0;
+        processedLabel          = 0;
+        failedLabel             = 0;
     }
 
+    int                       total;
+    int                       processed;
+    int                       failed;
+
+    QLabel*                   totalLabel;
+    QLabel*                   processedLabel;
+    QLabel*                   failedLabel;
+
     bool                      busy;
     bool                      hasLocator;
     int                       runtype;
@@ -186,8 +200,8 @@ RemoveRedEyesWindow::RemoveRedEyesWindow(KIPI::Interface *interface)
     d->locatorSettingsWidget = new QWidget;
 
     QVBoxLayout* mainSettingsLayout = new QVBoxLayout;
-    d->unprocessedSettingsBox = new UnprocessedSettingsBox;
-    d->storageSettingsBox     = new StorageSettingsBox;
+    d->unprocessedSettingsBox       = new UnprocessedSettingsBox;
+    d->storageSettingsBox           = new StorageSettingsBox;
     mainSettingsLayout->addWidget(d->storageSettingsBox);
     mainSettingsLayout->addWidget(d->unprocessedSettingsBox);
     mainSettingsLayout->addStretch(10);
@@ -199,9 +213,41 @@ RemoveRedEyesWindow::RemoveRedEyesWindow(KIPI::Interface *interface)
 
     // ----------------------------------------------------------
 
+    d->totalLabel     = new QLabel;
+    d->processedLabel = new QLabel;
+    d->failedLabel    = new QLabel;
+
+    d->totalLabel->setAlignment(Qt::AlignRight | Qt::AlignTop);
+    d->processedLabel->setAlignment(Qt::AlignRight | Qt::AlignTop);
+    d->failedLabel->setAlignment(Qt::AlignRight | Qt::AlignTop);
+
+    QLabel* l1 = new QLabel(i18nc("The total number of images in the list",
+            "Total:"));
+    QLabel* l2 = new QLabel(i18nc("number of images successfully processed",
+            "Success:"));
+    QLabel* l3 = new QLabel(i18nc("number of images failed to process",
+            "Failed:"));
+
+    QWidget* summaryBox           = new QWidget;
+    QHBoxLayout* summaryBoxLayout = new QHBoxLayout;
+    summaryBoxLayout->addWidget(l1);
+    summaryBoxLayout->addWidget(d->totalLabel);
+    summaryBoxLayout->addStretch(10);
+    summaryBoxLayout->addWidget(l2);
+    summaryBoxLayout->addWidget(d->processedLabel);
+    summaryBoxLayout->addWidget(l3);
+    summaryBoxLayout->addWidget(d->failedLabel);
+    summaryBox->setLayout(summaryBoxLayout);
+
+    // --------------------------------------------------------
+
     QWidget* imagesTab           = new QWidget;
-    QVBoxLayout* imagesTabLayout = new QVBoxLayout;
-    imagesTabLayout->addWidget(d->imageList);
+    QGridLayout* imagesTabLayout = new QGridLayout();
+    imagesTabLayout->addWidget(d->imageList, 0, 0, 1, 1);
+    imagesTabLayout->addWidget(summaryBox,   1, 0, 1, 1);
+    imagesTabLayout->setRowStretch(0, 10);
+    imagesTabLayout->setMargin(0);
+    imagesTabLayout->setSpacing(0);
     imagesTab->setLayout(imagesTabLayout);
 
     // ----------------------------------------------------------
@@ -213,13 +259,12 @@ RemoveRedEyesWindow::RemoveRedEyesWindow(KIPI::Interface *interface)
 
     // ----------------------------------------------------------
 
+    d->tabWidget->insertTab(FileList, imagesTab,      i18n("File List"));
+    d->tabWidget->insertTab(Settings, d->settingsTab, i18n("Settings"));
+//    d->tabWidget->insertTab(Preview,  previewTab,     i18n("Preview"));
+
     QWidget* mainWidget     = new QWidget;
     QVBoxLayout* mainLayout = new QVBoxLayout;
-
-    d->tabWidget->insertTab(FileList, imagesTab,        i18n("File List"));
-    d->tabWidget->insertTab(Settings, d->settingsTab,   i18n("Settings"));
-//    d->tabWidget->insertTab(Preview,  previewTab,       i18n("Preview"));
-
     mainLayout->addWidget(d->tabWidget, 5);
     mainLayout->addWidget(d->progress);
     mainWidget->setLayout(mainLayout);
@@ -238,6 +283,9 @@ RemoveRedEyesWindow::RemoveRedEyesWindow(KIPI::Interface *interface)
     connect(d->imageList, SIGNAL(signalFoundRAWImages(bool)),
             this, SLOT(foundRAWImages(bool)));
 
+    connect(d->imageList, SIGNAL(signalImageListChanged()),
+            this, SLOT(updateSummary()));
+
     connect(this, SIGNAL(user1Clicked()),
             this, SLOT(startCorrection()));
 
@@ -269,6 +317,10 @@ RemoveRedEyesWindow::RemoveRedEyesWindow(KIPI::Interface *interface)
     // ----------------------------------------------------------
 
     readSettings();
+    setBusy(false);
+    resetSummary();
+    updateSummary();
+    imageListChanged();
 }
 
 RemoveRedEyesWindow::~RemoveRedEyesWindow()
@@ -480,8 +532,8 @@ void RemoveRedEyesWindow::setBusy(bool busy)
     {
         // disable connection to make sure that the "test run" and "correct photos"
         // buttons are not enabled again on ImageListChange
-        disconnect(d->imageList, SIGNAL(signalImageListChanged(bool)),
-                this, SLOT(imageListChanged(bool)));
+        disconnect(d->imageList, SIGNAL(signalImageListChanged()),
+                this, SLOT(imageListChanged()));
 
         disconnect(this, SIGNAL(myCloseClicked()),
                    this, SLOT(closeClicked()));
@@ -499,8 +551,8 @@ void RemoveRedEyesWindow::setBusy(bool busy)
     {
         // enable connection again to make sure that an empty image list will
         // disable the "test run" and "correct photos" buttons
-        connect(d->imageList, SIGNAL(signalImageListChanged(bool)),
-                this, SLOT(imageListChanged(bool)));
+        connect(d->imageList, SIGNAL(signalImageListChanged()),
+                this, SLOT(imageListChanged()));
 
         disconnect(this, SIGNAL(myCloseClicked()),
                    this, SLOT(cancelCorrection()));
@@ -547,7 +599,7 @@ void RemoveRedEyesWindow::handleUnprocessedImages()
     }
 }
 
-void RemoveRedEyesWindow::imageListChanged(bool)
+void RemoveRedEyesWindow::imageListChanged()
 {
     bool isEmpty = d->imageList->imageUrls().isEmpty();
     enableButton(User1, !isEmpty);  // correction button
@@ -649,7 +701,7 @@ void RemoveRedEyesWindow::showSummary()
 {
     QString message = i18np("<p>%1 image has been successfully processed.</p>",
                             "<p>%1 images have been successfully processed.</p>",
-                            d->imageList->processedImages());
+                            processedImages());
     message.append(i18n("<h2>Correction Complete</h2>"));
 
     KMessageBox::information(this, message, i18n("Correction Complete"));
@@ -727,4 +779,50 @@ void RemoveRedEyesWindow::locatorChanged()
     }
 }
 
+int RemoveRedEyesWindow::totalImages() const
+{
+    return d->total;
+}
+
+int RemoveRedEyesWindow::processedImages() const
+{
+    return d->processed;
+}
+
+int RemoveRedEyesWindow::failedImages() const
+{
+    return d->failed;
+}
+
+void RemoveRedEyesWindow::resetSummary()
+{
+    d->total       = d->imageList->imageUrls().count();
+    d->processed   = 0;
+    d->failed      = 0;
+}
+
+void RemoveRedEyesWindow::updateSummary()
+{
+    resetSummary();
+
+    QTreeWidgetItemIterator it(d->imageList->listView());
+    while (*it)
+    {
+        ImagesListViewItem* item = dynamic_cast<ImagesListViewItem*>(*it);
+        if (!item->text(ImagesListView::User1).isEmpty())
+        {
+            if (item->text(ImagesListView::User1).toInt() > 0)
+                d->processed++;
+            else
+                d->failed++;
+        }
+        ++it;
+    }
+
+    d->totalLabel->setText(QString("%1").arg(d->total));
+    d->processedLabel->setText(QString("%1").arg(d->processed));
+    d->failedLabel->setText(QString("%1").arg(d->failed));
+}
+
+
 } // namespace KIPIRemoveRedEyesPlugin
