@@ -24,7 +24,7 @@
 #include "smugtalker.h"
 #include "smugtalker.moc"
 
-// Qt includes.
+// Qt includes
 #include <QByteArray>
 #include <QDomDocument>
 #include <QDomElement>
@@ -33,13 +33,13 @@
 #include <QFileInfo>
 #include <QProgressDialog>
 
-// KDE includes.
+// KDE includes
 #include <KCodecs>
 #include <KDebug>
 #include <KIO/Job>
 #include <KIO/JobUiDelegate>
 
-// Local includes.
+// Local includes
 #include "pluginsversion.h"
 #include "smugitem.h"
 
@@ -95,7 +95,7 @@ void SmugTalker::login(const QString& email, const QString& password)
         m_job = 0;
     }
     emit signalBusy(true);
-    emit signalLoginProgress(1, 4, i18n("Logging to SmugMug service..."));
+    emit signalLoginProgress(1, 4, i18n("Logging in to SmugMug service..."));
 
     KUrl url(m_apiURL);
     if (email.isEmpty()) 
